/* Resources.c generated by valac 0.32.1, the Vala compiler
 * generated from Resources.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */
/* defined by ./configure or Makefile and included by gcc -D*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtk.h>
#include <gee.h>
#include <gio/gio.h>
#include <locale.h>
#include <langinfo.h>
#include <gdk/gdk.h>

#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_RATING (rating_get_type ())

#define TYPE_RATING_FILTER (rating_filter_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _gtk_icon_set_unref0(var) ((var == NULL) ? NULL : (var = (gtk_icon_set_unref (var), NULL)))
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))

typedef enum  {
	RATING_REJECTED = -1,
	RATING_UNRATED = 0,
	RATING_ONE = 1,
	RATING_TWO = 2,
	RATING_THREE = 3,
	RATING_FOUR = 4,
	RATING_FIVE = 5
} Rating;

typedef enum  {
	RATING_FILTER_NO_FILTER = 0,
	RATING_FILTER_REJECTED_OR_HIGHER = 1,
	RATING_FILTER_UNRATED_OR_HIGHER = 2,
	RATING_FILTER_ONE_OR_HIGHER = 3,
	RATING_FILTER_TWO_OR_HIGHER = 4,
	RATING_FILTER_THREE_OR_HIGHER = 5,
	RATING_FILTER_FOUR_OR_HIGHER = 6,
	RATING_FILTER_FIVE_OR_HIGHER = 7,
	RATING_FILTER_REJECTED_ONLY = 8,
	RATING_FILTER_UNRATED_ONLY = 9,
	RATING_FILTER_ONE_ONLY = 10,
	RATING_FILTER_TWO_ONLY = 11,
	RATING_FILTER_THREE_ONLY = 12,
	RATING_FILTER_FOUR_ONLY = 13,
	RATING_FILTER_FIVE_ONLY = 14
} RatingFilter;

typedef void (*ResourcesAddStockIconModify) (GdkPixbuf* pixbuf, void* user_data);

extern gchar* resources_RATE_ONE_MENU;
extern gchar* resources_RATE_TWO_MENU;
extern gchar* resources_RATE_THREE_MENU;
extern gchar* resources_RATE_FOUR_MENU;
extern gchar* resources_RATE_FIVE_MENU;
extern gchar* resources_RATE_ONE_LABEL;
extern gchar* resources_RATE_TWO_LABEL;
extern gchar* resources_RATE_THREE_LABEL;
extern gchar* resources_RATE_FOUR_LABEL;
extern gchar* resources_RATE_FIVE_LABEL;
extern gchar* resources_DISPLAY_ONE_OR_HIGHER_TOOLTIP;
extern gchar* resources_DISPLAY_TWO_OR_HIGHER_TOOLTIP;
extern gchar* resources_DISPLAY_THREE_OR_HIGHER_TOOLTIP;
extern gchar* resources_DISPLAY_FOUR_OR_HIGHER_TOOLTIP;
extern gchar* resources_DISPLAY_FIVE_OR_HIGHER_TOOLTIP;
extern gchar* resources_RATE_ONE_PROGRESS;
extern gchar* resources_RATE_TWO_PROGRESS;
extern gchar* resources_RATE_THREE_PROGRESS;
extern gchar* resources_RATE_FOUR_PROGRESS;
extern gchar* resources_RATE_FIVE_PROGRESS;
extern gchar* resources_RATE_ONE_TOOLTIP;
extern gchar* resources_RATE_TWO_TOOLTIP;
extern gchar* resources_RATE_THREE_TOOLTIP;
extern gchar* resources_RATE_FOUR_TOOLTIP;
extern gchar* resources_RATE_FIVE_TOOLTIP;
extern gchar* resources_DISPLAY_ONE_OR_HIGHER_MENU;
extern gchar* resources_DISPLAY_TWO_OR_HIGHER_MENU;
extern gchar* resources_DISPLAY_THREE_OR_HIGHER_MENU;
extern gchar* resources_DISPLAY_FOUR_OR_HIGHER_MENU;
extern gchar* resources_DISPLAY_FIVE_OR_HIGHER_MENU;
extern gchar* resources_DISPLAY_ONE_OR_HIGHER_LABEL;
extern gchar* resources_DISPLAY_TWO_OR_HIGHER_LABEL;
extern gchar* resources_DISPLAY_THREE_OR_HIGHER_LABEL;
extern gchar* resources_DISPLAY_FOUR_OR_HIGHER_LABEL;
extern gchar* resources_DISPLAY_FIVE_OR_HIGHER_LABEL;
gchar* resources_RATE_ONE_MENU = NULL;
gchar* resources_RATE_ONE_LABEL = NULL;
gchar* resources_RATE_ONE_TOOLTIP = NULL;
gchar* resources_RATE_ONE_PROGRESS = NULL;
gchar* resources_RATE_TWO_MENU = NULL;
gchar* resources_RATE_TWO_LABEL = NULL;
gchar* resources_RATE_TWO_TOOLTIP = NULL;
gchar* resources_RATE_TWO_PROGRESS = NULL;
gchar* resources_RATE_THREE_MENU = NULL;
gchar* resources_RATE_THREE_LABEL = NULL;
gchar* resources_RATE_THREE_TOOLTIP = NULL;
gchar* resources_RATE_THREE_PROGRESS = NULL;
gchar* resources_RATE_FOUR_MENU = NULL;
gchar* resources_RATE_FOUR_LABEL = NULL;
gchar* resources_RATE_FOUR_TOOLTIP = NULL;
gchar* resources_RATE_FOUR_PROGRESS = NULL;
gchar* resources_RATE_FIVE_MENU = NULL;
gchar* resources_RATE_FIVE_LABEL = NULL;
gchar* resources_RATE_FIVE_TOOLTIP = NULL;
gchar* resources_RATE_FIVE_PROGRESS = NULL;
gchar* resources_DISPLAY_ONE_OR_HIGHER_MENU = NULL;
gchar* resources_DISPLAY_ONE_OR_HIGHER_LABEL = NULL;
gchar* resources_DISPLAY_ONE_OR_HIGHER_TOOLTIP = NULL;
gchar* resources_DISPLAY_TWO_OR_HIGHER_MENU = NULL;
gchar* resources_DISPLAY_TWO_OR_HIGHER_LABEL = NULL;
gchar* resources_DISPLAY_TWO_OR_HIGHER_TOOLTIP = NULL;
gchar* resources_DISPLAY_THREE_OR_HIGHER_MENU = NULL;
gchar* resources_DISPLAY_THREE_OR_HIGHER_LABEL = NULL;
gchar* resources_DISPLAY_THREE_OR_HIGHER_TOOLTIP = NULL;
gchar* resources_DISPLAY_FOUR_OR_HIGHER_MENU = NULL;
gchar* resources_DISPLAY_FOUR_OR_HIGHER_LABEL = NULL;
gchar* resources_DISPLAY_FOUR_OR_HIGHER_TOOLTIP = NULL;
gchar* resources_DISPLAY_FIVE_OR_HIGHER_MENU = NULL;
gchar* resources_DISPLAY_FIVE_OR_HIGHER_LABEL = NULL;
gchar* resources_DISPLAY_FIVE_OR_HIGHER_TOOLTIP = NULL;
extern GtkIconFactory* resources_factory;
GtkIconFactory* resources_factory = NULL;
extern GeeHashMap* resources_icon_cache;
GeeHashMap* resources_icon_cache = NULL;
extern GeeHashMap* resources_scaled_icon_cache;
GeeHashMap* resources_scaled_icon_cache = NULL;
extern gchar* resources_HH_MM_FORMAT_STRING;
gchar* resources_HH_MM_FORMAT_STRING = NULL;
extern gchar* resources_HH_MM_SS_FORMAT_STRING;
gchar* resources_HH_MM_SS_FORMAT_STRING = NULL;
extern gchar* resources_LONG_DATE_FORMAT_STRING;
gchar* resources_LONG_DATE_FORMAT_STRING = NULL;
extern gchar* resources_START_MULTIDAY_DATE_FORMAT_STRING;
gchar* resources_START_MULTIDAY_DATE_FORMAT_STRING = NULL;
extern gchar* resources_END_MULTIDAY_DATE_FORMAT_STRING;
gchar* resources_END_MULTIDAY_DATE_FORMAT_STRING = NULL;
extern gchar* resources_START_MULTIMONTH_DATE_FORMAT_STRING;
gchar* resources_START_MULTIMONTH_DATE_FORMAT_STRING = NULL;
extern gchar* resources_END_MULTIMONTH_DATE_FORMAT_STRING;
gchar* resources_END_MULTIMONTH_DATE_FORMAT_STRING = NULL;
extern GdkPixbuf* resources_noninterpretable_badge_pixbuf;
GdkPixbuf* resources_noninterpretable_badge_pixbuf = NULL;
extern GeeMap* resources_providers;
GeeMap* resources_providers = NULL;

#define RESOURCES_APP_TITLE "Shotwell"
#define RESOURCES_APP_LIBRARY_ROLE _ ("Photo Manager")
#define RESOURCES_APP_DIRECT_ROLE _ ("Photo Viewer")
#define RESOURCES_APP_VERSION _VERSION
#define RESOURCES_GIT_VERSION _GIT_VERSION
#define RESOURCES_COPYRIGHT _ ("Copyright 2016 Software Freedom Conservancy Inc.")
#define RESOURCES_APP_GETTEXT_PACKAGE GETTEXT_PACKAGE
#define RESOURCES_HOME_URL "https://wiki.gnome.org/Apps/Shotwell"
#define RESOURCES_FAQ_URL "https://wiki.gnome.org/Apps/Shotwell/FAQ"
#define RESOURCES_BUG_DB_URL "https://wiki.gnome.org/Apps/Shotwell/ReportingABug"
#define RESOURCES_DIR_PATTERN_URI_SYSWIDE "help:shotwell/other-files"
#define RESOURCES_LIB _LIB
#define RESOURCES_LIBEXECDIR _LIBEXECDIR
#define RESOURCES_PREFIX _PREFIX
#define RESOURCES_TRANSIENT_WINDOW_OPACITY 0.90
#define RESOURCES_DEFAULT_ICON_SCALE 24
#define RESOURCES_LICENSE "\n" \
"Shotwell is free software; you can redistribute it and/or modify it un" \
"der the \n" \
"terms of the GNU Lesser General Public License as published by the Fre" \
"e \n" \
"Software Foundation; either version 2.1 of the License, or (at your op" \
"tion) \n" \
"any later version.\n" \
"\n" \
"Shotwell is distributed in the hope that it will be useful, but WITHOU" \
"T \n" \
"ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or " \
"FITNESS\n" \
"FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License f" \
"or \n" \
"more details.\n" \
"\n" \
"You should have received a copy of the GNU Lesser General Public Licen" \
"se \n" \
"along with Shotwell; if not, write to the Free Software Foundation, In" \
"c., \n" \
"51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA\n"
#define RESOURCES_CLOCKWISE "object-rotate-right"
#define RESOURCES_COUNTERCLOCKWISE "object-rotate-left"
#define RESOURCES_HFLIP "object-flip-horizontal"
#define RESOURCES_VFLIP "object-flip-vertical"
#define RESOURCES_CROP "shotwell-crop"
#define RESOURCES_STRAIGHTEN "shotwell-straighten"
#define RESOURCES_REDEYE "shotwell-redeye"
#define RESOURCES_ADJUST "image-adjust"
#define RESOURCES_PIN_TOOLBAR "shotwell-pin-toolbar"
#define RESOURCES_MAKE_PRIMARY "shotwell-make-primary"
#define RESOURCES_IMPORT "shotwell-import"
#define RESOURCES_IMPORT_ALL "shotwell-import-all"
#define RESOURCES_ENHANCE "shotwell-auto-enhance"
#define RESOURCES_CROP_PIVOT_RETICLE "shotwell-crop-pivot-reticle"
#define RESOURCES_PUBLISH "applications-internet"
#define RESOURCES_MERGE "shotwell-merge-events"
#define RESOURCES_GO_NEXT "go-next"
#define RESOURCES_GO_PREVIOUS "go-previous"
#define RESOURCES_ICON_ABOUT_LOGO "shotwell-street.jpg"
#define RESOURCES_ICON_GENERIC_PLUGIN "generic-plugin.png"
#define RESOURCES_ICON_SLIDESHOW_EXTENSION_POINT "slideshow-extension-point"
#define RESOURCES_ICON_RATING_REJECTED "rejected.svg"
#define RESOURCES_ICON_RATING_ONE "one-star.svg"
#define RESOURCES_ICON_RATING_TWO "two-stars.svg"
#define RESOURCES_ICON_RATING_THREE "three-stars.svg"
#define RESOURCES_ICON_RATING_FOUR "four-stars.svg"
#define RESOURCES_ICON_RATING_FIVE "five-stars.svg"
#define RESOURCES_ICON_FILTER_REJECTED_OR_BETTER "all-rejected.png"
#define RESOURCES_ICON_FILTER_REJECTED_OR_BETTER_FIXED_SIZE 32
#define RESOURCES_ICON_FILTER_UNRATED_OR_BETTER "shotwell-16.png"
#define RESOURCES_ICON_FILTER_UNRATED_OR_BETTER_FIXED_SIZE 16
#define RESOURCES_ICON_FILTER_ONE_OR_BETTER "one-star-filter-plus.svg"
#define RESOURCES_ICON_FILTER_TWO_OR_BETTER "two-star-filter-plus.svg"
#define RESOURCES_ICON_FILTER_THREE_OR_BETTER "three-star-filter-plus.svg"
#define RESOURCES_ICON_FILTER_FOUR_OR_BETTER "four-star-filter-plus.svg"
#define RESOURCES_ICON_FILTER_FIVE "five-star-filter.svg"
#define RESOURCES_ICON_ZOOM_IN "zoom-in.png"
#define RESOURCES_ICON_ZOOM_OUT "zoom-out.png"
#define RESOURCES_ICON_ZOOM_SCALE 16
#define RESOURCES_ICON_CAMERAS "camera-photo"
#define RESOURCES_ICON_EVENTS "multiple-events"
#define RESOURCES_ICON_ONE_EVENT "one-event"
#define RESOURCES_ICON_NO_EVENT "no-event"
#define RESOURCES_ICON_ONE_TAG "one-tag"
#define RESOURCES_ICON_TAGS "multiple-tags"
#define RESOURCES_ICON_FOLDER "folder"
#define RESOURCES_ICON_FOLDER_DOCUMENTS "folder-documents"
#define RESOURCES_ICON_IMPORTING "go-down"
#define RESOURCES_ICON_LAST_IMPORT "document-open-recent"
#define RESOURCES_ICON_MISSING_FILES "process-stop"
#define RESOURCES_ICON_PHOTOS "shotwell"
#define RESOURCES_ICON_SINGLE_PHOTO "image-x-generic"
#define RESOURCES_ICON_FILTER_PHOTOS "filter-photos"
#define RESOURCES_ICON_FILTER_PHOTOS_DISABLED "filter-photos-disabled"
#define RESOURCES_ICON_FILTER_VIDEOS "filter-videos"
#define RESOURCES_ICON_FILTER_VIDEOS_DISABLED "filter-videos-disabled"
#define RESOURCES_ICON_FILTER_RAW "filter-raw"
#define RESOURCES_ICON_FILTER_RAW_DISABLED "filter-raw-disabled"
#define RESOURCES_ICON_FILTER_FLAGGED "filter-flagged"
#define RESOURCES_ICON_FILTER_FLAGGED_DISABLED "filter-flagged-disabled"
#define RESOURCES_ICON_TRASH_EMPTY "user-trash"
#define RESOURCES_ICON_TRASH_FULL "user-trash-full"
#define RESOURCES_ICON_VIDEOS_PAGE "videos-page"
#define RESOURCES_ICON_FLAGGED_PAGE "flag-page"
#define RESOURCES_ICON_FLAGGED_TRINKET "flag-trinket.png"
#define RESOURCES_ROTATE_CW_MENU _ ("Rotate _Right")
#define RESOURCES_ROTATE_CW_LABEL _ ("Rotate")
#define RESOURCES_ROTATE_CW_FULL_LABEL _ ("Rotate Right")
#define RESOURCES_ROTATE_CW_TOOLTIP _ ("Rotate the photos right (press Ctrl to rotate left)")
#define RESOURCES_ROTATE_CCW_MENU _ ("Rotate _Left")
#define RESOURCES_ROTATE_CCW_LABEL _ ("Rotate")
#define RESOURCES_ROTATE_CCW_FULL_LABEL _ ("Rotate Left")
#define RESOURCES_ROTATE_CCW_TOOLTIP _ ("Rotate the photos left")
#define RESOURCES_HFLIP_MENU _ ("Flip Hori_zontally")
#define RESOURCES_HFLIP_LABEL _ ("Flip Horizontally")
#define RESOURCES_VFLIP_MENU _ ("Flip Verti_cally")
#define RESOURCES_VFLIP_LABEL _ ("Flip Vertically")
#define RESOURCES_ABOUT_LABEL _ ("_About")
#define RESOURCES_APPLY_LABEL _ ("_Apply")
#define RESOURCES_CANCEL_LABEL _ ("_Cancel")
#define RESOURCES_DELETE_LABEL _ ("_Delete")
#define RESOURCES_EDIT_LABEL _ ("_Edit")
#define RESOURCES_FORWARD_LABEL _ ("_Forward")
#define RESOURCES_FULLSCREEN_LABEL _ ("Fulls_creen")
#define RESOURCES_HELP_LABEL _ ("_Help")
#define RESOURCES_LEAVE_FULLSCREEN_LABEL _ ("Leave _Fullscreen")
#define RESOURCES_NEW_LABEL _ ("_New")
#define RESOURCES_NEXT_LABEL _ ("_Next")
#define RESOURCES_OK_LABEL _ ("_OK")
#define RESOURCES_PLAY_LABEL _ ("_Play")
#define RESOURCES_PREFERENCES_LABEL _ ("_Preferences")
#define RESOURCES_PREVIOUS_LABEL _ ("_Previous")
#define RESOURCES_PRINT_LABEL _ ("_Print")
#define RESOURCES_QUIT_LABEL _ ("_Quit")
#define RESOURCES_REFRESH_LABEL _ ("_Refresh")
#define RESOURCES_REMOVE_LABEL _ ("_Remove")
#define RESOURCES_REVERT_TO_SAVED_LABEL _ ("_Revert")
#define RESOURCES_SAVE_LABEL _ ("_Save")
#define RESOURCES_SAVE_AS_LABEL _ ("Save _As")
#define RESOURCES_SORT_ASCENDING_LABEL _ ("Sort _Ascending")
#define RESOURCES_SORT_DESCENDING_LABEL _ ("Sort _Descending")
#define RESOURCES_STOP_LABEL _ ("_Stop")
#define RESOURCES_UNDELETE_LABEL _ ("_Undelete")
#define RESOURCES_ZOOM_100_LABEL _ ("_Normal Size")
#define RESOURCES_ZOOM_FIT_LABEL _ ("Best _Fit")
#define RESOURCES_ZOOM_IN_LABEL _ ("Zoom _In")
#define RESOURCES_ZOOM_OUT_LABEL _ ("Zoom _Out")
#define RESOURCES_ENHANCE_MENU _ ("_Enhance")
#define RESOURCES_ENHANCE_LABEL _ ("Enhance")
#define RESOURCES_ENHANCE_TOOLTIP _ ("Automatically improve the photo's appearance")
#define RESOURCES_COPY_ADJUSTMENTS_MENU _ ("_Copy Color Adjustments")
#define RESOURCES_COPY_ADJUSTMENTS_LABEL _ ("Copy Color Adjustments")
#define RESOURCES_COPY_ADJUSTMENTS_TOOLTIP _ ("Copy the color adjustments applied to the photo")
#define RESOURCES_PASTE_ADJUSTMENTS_MENU _ ("_Paste Color Adjustments")
#define RESOURCES_PASTE_ADJUSTMENTS_LABEL _ ("Paste Color Adjustments")
#define RESOURCES_PASTE_ADJUSTMENTS_TOOLTIP _ ("Apply copied color adjustments to the selected photos")
#define RESOURCES_CROP_MENU _ ("_Crop")
#define RESOURCES_CROP_LABEL _ ("Crop")
#define RESOURCES_CROP_TOOLTIP _ ("Crop the photo's size")
#define RESOURCES_STRAIGHTEN_MENU _ ("_Straighten")
#define RESOURCES_STRAIGHTEN_LABEL _ ("Straighten")
#define RESOURCES_STRAIGHTEN_TOOLTIP _ ("Straighten the photo")
#define RESOURCES_RED_EYE_MENU _ ("_Red-eye")
#define RESOURCES_RED_EYE_LABEL _ ("Red-eye")
#define RESOURCES_RED_EYE_TOOLTIP _ ("Reduce or eliminate any red-eye effects in the photo")
#define RESOURCES_ADJUST_MENU _ ("_Adjust")
#define RESOURCES_ADJUST_LABEL _ ("Adjust")
#define RESOURCES_ADJUST_TOOLTIP _ ("Adjust the photo's color and tone")
#define RESOURCES_REVERT_MENU _ ("Re_vert to Original")
#define RESOURCES_REVERT_LABEL _ ("Revert to Original")
#define RESOURCES_REVERT_EDITABLE_MENU _ ("Revert External E_dits")
#define RESOURCES_REVERT_EDITABLE_TOOLTIP _ ("Revert to the master photo")
#define RESOURCES_SET_BACKGROUND_MENU _ ("Set as _Desktop Background")
#define RESOURCES_SET_BACKGROUND_TOOLTIP _ ("Set selected image to be the new desktop background")
#define RESOURCES_SET_BACKGROUND_SLIDESHOW_MENU _ ("Set as _Desktop Slideshow...")
#define RESOURCES_UNDO_MENU _ ("_Undo")
#define RESOURCES_UNDO_LABEL _ ("Undo")
#define RESOURCES_REDO_MENU _ ("_Redo")
#define RESOURCES_REDO_LABEL _ ("Redo")
#define RESOURCES_RENAME_EVENT_MENU _ ("Re_name Event...")
#define RESOURCES_RENAME_EVENT_LABEL _ ("Rename Event")
#define RESOURCES_MAKE_KEY_PHOTO_MENU _ ("Make _Key Photo for Event")
#define RESOURCES_MAKE_KEY_PHOTO_LABEL _ ("Make Key Photo for Event")
#define RESOURCES_NEW_EVENT_MENU _ ("_New Event")
#define RESOURCES_NEW_EVENT_LABEL _ ("New Event")
#define RESOURCES_SET_PHOTO_EVENT_LABEL _ ("Move Photos")
#define RESOURCES_SET_PHOTO_EVENT_TOOLTIP _ ("Move photos to an event")
#define RESOURCES_MERGE_MENU _ ("_Merge Events")
#define RESOURCES_MERGE_LABEL _ ("Merge")
#define RESOURCES_MERGE_TOOLTIP _ ("Combine events into a single event")
#define RESOURCES_RATING_MENU _ ("_Set Rating")
#define RESOURCES_RATING_LABEL _ ("Set Rating")
#define RESOURCES_RATING_TOOLTIP _ ("Change the rating of your photo")
#define RESOURCES_INCREASE_RATING_MENU _ ("_Increase")
#define RESOURCES_INCREASE_RATING_LABEL _ ("Increase Rating")
#define RESOURCES_DECREASE_RATING_MENU _ ("_Decrease")
#define RESOURCES_DECREASE_RATING_LABEL _ ("Decrease Rating")
#define RESOURCES_RATE_UNRATED_MENU _ ("_Unrated")
#define RESOURCES_RATE_UNRATED_COMBO_BOX _ ("Unrated")
#define RESOURCES_RATE_UNRATED_LABEL _ ("Rate Unrated")
#define RESOURCES_RATE_UNRATED_PROGRESS _ ("Setting as unrated")
#define RESOURCES_RATE_UNRATED_TOOLTIP _ ("Remove any ratings")
#define RESOURCES_RATE_REJECTED_MENU _ ("_Rejected")
#define RESOURCES_RATE_REJECTED_COMBO_BOX _ ("Rejected")
#define RESOURCES_RATE_REJECTED_LABEL _ ("Rate Rejected")
#define RESOURCES_RATE_REJECTED_PROGRESS _ ("Setting as rejected")
#define RESOURCES_RATE_REJECTED_TOOLTIP _ ("Set rating to rejected")
#define RESOURCES_DISPLAY_REJECTED_ONLY_MENU _ ("Rejected _Only")
#define RESOURCES_DISPLAY_REJECTED_ONLY_LABEL _ ("Rejected Only")
#define RESOURCES_DISPLAY_REJECTED_ONLY_TOOLTIP _ ("Show only rejected photos")
#define RESOURCES_DISPLAY_REJECTED_OR_HIGHER_MENU _ ("All + _Rejected")
#define RESOURCES_DISPLAY_REJECTED_OR_HIGHER_TOOLTIP "Show all photos, including rejected"
#define RESOURCES_DISPLAY_UNRATED_OR_HIGHER_MENU _ ("_All Photos")
#define RESOURCES_DISPLAY_UNRATED_OR_HIGHER_TOOLTIP _ ("Show all photos")
#define RESOURCES_VIEW_RATINGS_MENU _ ("_Ratings")
#define RESOURCES_VIEW_RATINGS_TOOLTIP _ ("Display each photo's rating")
#define RESOURCES_FILTER_PHOTOS_MENU _ ("_Filter Photos")
#define RESOURCES_FILTER_PHOTOS_LABEL _ ("Filter Photos")
#define RESOURCES_FILTER_PHOTOS_TOOLTIP _ ("Limit the number of photos displayed based on a filter")
#define RESOURCES_DUPLICATE_PHOTO_MENU _ ("_Duplicate")
#define RESOURCES_DUPLICATE_PHOTO_LABEL _ ("Duplicate")
#define RESOURCES_DUPLICATE_PHOTO_TOOLTIP _ ("Make a duplicate of the photo")
#define RESOURCES_EXPORT_MENU _ ("_Export...")
#define RESOURCES_PRINT_MENU _ ("_Print...")
#define RESOURCES_PUBLISH_MENU _ ("Pu_blish...")
#define RESOURCES_PUBLISH_LABEL _ ("Publish")
#define RESOURCES_PUBLISH_TOOLTIP _ ("Publish to various websites")
#define RESOURCES_EDIT_TITLE_MENU _ ("Edit _Title...")
#define RESOURCES_EDIT_TITLE_LABEL "Edit Title"
#define RESOURCES_EDIT_COMMENT_MENU _ ("Edit _Comment...")
#define RESOURCES_EDIT_COMMENT_LABEL _ ("Edit Comment")
#define RESOURCES_EDIT_EVENT_COMMENT_MENU _ ("Edit Event _Comment...")
#define RESOURCES_EDIT_EVENT_COMMENT_LABEL _ ("Edit Event Comment")
#define RESOURCES_ADJUST_DATE_TIME_MENU _ ("_Adjust Date and Time...")
#define RESOURCES_ADJUST_DATE_TIME_LABEL _ ("Adjust Date and Time")
#define RESOURCES_ADD_TAGS_MENU _ ("Add _Tags...")
#define RESOURCES_ADD_TAGS_CONTEXT_MENU _ ("_Add Tags...")
#define RESOURCES_ADD_TAGS_TITLE "Add Tags"
#define RESOURCES_PREFERENCES_MENU _ ("_Preferences")
#define RESOURCES_EXTERNAL_EDIT_MENU _ ("Open With E_xternal Editor")
#define RESOURCES_EXTERNAL_EDIT_RAW_MENU _ ("Open With RA_W Editor")
#define RESOURCES_SEND_TO_MENU _ ("Send _To...")
#define RESOURCES_SEND_TO_CONTEXT_MENU _ ("Send T_o...")
#define RESOURCES_FIND_MENU _ ("_Find...")
#define RESOURCES_FIND_LABEL _ ("Find")
#define RESOURCES_FIND_TOOLTIP _ ("Find an image by typing text that appears in its name or tags")
#define RESOURCES_FLAG_MENU _ ("_Flag")
#define RESOURCES_UNFLAG_MENU _ ("Un_flag")
gchar* resources_launch_editor_failed (GError* err);
gchar* resources_add_tags_label (gchar** names, int names_length1);
gchar* hierarchical_tag_utilities_get_basename (const gchar* in_path);
gchar* resources_delete_tag_menu (const gchar* name);
gchar* resources_delete_tag_label (const gchar* name);
#define RESOURCES_DELETE_TAG_TITLE _ ("Delete Tag")
#define RESOURCES_DELETE_TAG_SIDEBAR_MENU _ ("_Delete")
#define RESOURCES_NEW_CHILD_TAG_SIDEBAR_MENU _ ("_New")
gchar* resources_rename_tag_menu (const gchar* name);
gchar* resources_rename_tag_label (const gchar* old_name, const gchar* new_name);
#define RESOURCES_RENAME_TAG_SIDEBAR_MENU _ ("_Rename...")
#define RESOURCES_MODIFY_TAGS_MENU _ ("Modif_y Tags...")
#define RESOURCES_MODIFY_TAGS_LABEL _ ("Modify Tags")
gchar* resources_tag_photos_label (const gchar* name, gint count);
gchar* resources_tag_photos_tooltip (const gchar* name, gint count);
gchar* resources_untag_photos_menu (const gchar* name, gint count);
gchar* resources_untag_photos_label (const gchar* name, gint count);
gchar* resources_rename_tag_exists_message (const gchar* name);
gchar* resources_rename_search_exists_message (const gchar* name);
#define RESOURCES_DEFAULT_SAVED_SEARCH_NAME _ ("Saved Search")
#define RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE _ ("Delete Search")
#define RESOURCES_DELETE_SEARCH_MENU _ ("_Delete")
#define RESOURCES_EDIT_SEARCH_MENU _ ("_Edit...")
#define RESOURCES_RENAME_SEARCH_MENU _ ("Re_name...")
gchar* resources_rename_search_label (const gchar* old_name, const gchar* new_name);
gchar* resources_delete_search_label (const gchar* name);
GType rating_get_type (void) G_GNUC_CONST;
const gchar* resources_rating_menu (Rating rating);
const gchar* resources_rating_label (Rating rating);
const gchar* resources_rating_combo_box (Rating rating);
GType rating_filter_get_type (void) G_GNUC_CONST;
gchar* resources_get_rating_filter_tooltip (RatingFilter filter);
gchar* resources_rating_progress (Rating rating);
gchar* resources_get_stars (Rating rating);
GdkPixbuf* resources_get_rating_trinket (Rating rating, gint scale);
GdkPixbuf* resources_get_icon (const gchar* name, gint scale);
void resources_generate_rating_strings (void);
#define RESOURCES_DELETE_PHOTOS_MENU _ ("_Delete")
#define RESOURCES_DELETE_FROM_TRASH_TOOLTIP _ ("Remove the selected photos from the trash")
#define RESOURCES_DELETE_FROM_LIBRARY_TOOLTIP _ ("Remove the selected photos from the library")
#define RESOURCES_RESTORE_PHOTOS_MENU _ ("_Restore")
#define RESOURCES_RESTORE_PHOTOS_TOOLTIP _ ("Move the selected photos back into the library")
#define RESOURCES_JUMP_TO_FILE_MENU _ ("Show in File Mana_ger")
#define RESOURCES_JUMP_TO_FILE_TOOLTIP _ ("Open the selected photo's directory in the file manager")
gchar* resources_jump_to_file_failed (GError* err);
#define RESOURCES_REMOVE_FROM_LIBRARY_MENU _ ("R_emove From Library")
#define RESOURCES_MOVE_TO_TRASH_MENU _ ("_Move to Trash")
#define RESOURCES_SELECT_ALL_MENU _ ("Select _All")
#define RESOURCES_SELECT_ALL_TOOLTIP _ ("Select all items")
void resources_init (void);
GFile* app_dirs_get_resources_dir (void);
void resources_add_stock_icon (GFile* file, const gchar* stock_id);
void resources_add_stock_icon_from_themed_icon (GThemedIcon* gicon, const gchar* stock_id, ResourcesAddStockIconModify modify, void* modify_target);
void dim_pixbuf (GdkPixbuf* pixbuf);
static void _dim_pixbuf_resources_add_stock_icon_modify (GdkPixbuf* pixbuf, gpointer self);
void resources_terminate (void);
void resources_fetch_lc_time_format (void);
gchar* resources_get_hh_mm_format_string (void);
gchar* resources_get_hh_mm_ss_format_string (void);
gchar* resources_get_long_date_format_string (void);
gchar* resources_get_start_multiday_span_format_string (void);
gchar* resources_get_end_multiday_span_format_string (void);
gchar* resources_get_start_multimonth_span_format_string (void);
gchar* resources_get_end_multimonth_span_format_string (void);
GFile* resources_get_ui (const gchar* filename);
#define RESOURCES_NONINTERPRETABLE_BADGE_FILE "noninterpretable-video.png"
GdkPixbuf* resources_get_noninterpretable_badge_pixbuf (void);
GtkIconTheme* resources_get_icon_theme_engine (void);
GdkPixbuf* resources_load_icon (const gchar* name, gint scale);
GdkPixbuf* scale_pixbuf (GdkPixbuf* pixbuf, gint scale, GdkInterpType interp, gboolean scale_up);
gchar* resources_get_help_path (void);
GFile* app_dirs_get_exec_dir (void);
void resources_launch_help (GdkScreen* screen, const gchar* anchor, GError** error);
void sys_show_uri (GdkScreen* screen, const gchar* uri, GError** error);
gchar* resources_to_css_color (GdkRGBA* color);
#define RESOURCES_ALL_DATA -1
void resources_style_widget (GtkWidget* widget, const gchar* stylesheet);
#define RESOURCES_CUSTOM_CSS "LibraryWindow * {\n" \
"               -GtkPaned-handle-size: 1;\n" \
"            }\n" \
"            LibraryWindow .pane-separator {\n" \
"               background-color: @borders;\n" \
"            }\n" \
"            SearchFilterToolbar {\n" \
"               border-width: 0 0 1px 0;\n" \
"               border-style: solid;\n" \
"               border-color: @borders;\n" \
"            }"
#define RESOURCES_ONIMAGE_FONT_COLOR "#000000"
#define RESOURCES_ONIMAGE_FONT_BACKGROUND "rgba(255,255,255,0.5)"
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

const gchar* RESOURCES_AUTHORS[6] = {"Jim Nelson <jim@yorba.org>", "Lucas Beeler <lucas@yorba.org>", "Allison Barlow <allison@yorba.org>", "Eric Gregory <eric@yorba.org>", "Clinton Rogers <clinton@yorba.org>", NULL};
const gint RESOURCES_rating_thresholds[6] = {0, 1, 25, 50, 75, 99};

gchar* resources_launch_editor_failed (GError* err) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 335 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Unable to launch editor: %s");
#line 335 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = err;
#line 335 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = _tmp1_->message;
#line 335 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = g_strdup_printf (_tmp0_, _tmp2_);
#line 335 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp3_;
#line 335 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 491 "Resources.c"
}


gchar* resources_add_tags_label (gchar** names, int names_length1) {
	gchar* result = NULL;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 339 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = names;
#line 339 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0__length1 = names_length1;
#line 339 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0__length1 == 1) {
#line 505 "Resources.c"
		const gchar* _tmp1_ = NULL;
		gchar** _tmp2_ = NULL;
		gint _tmp2__length1 = 0;
		const gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp1_ = _ ("Add Tag \"%s\"");
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2_ = names;
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2__length1 = names_length1;
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp3_ = _tmp2_[0];
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp4_ = hierarchical_tag_utilities_get_basename (_tmp3_);
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp5_ = _tmp4_;
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp6_ = g_strdup_printf (_tmp1_, _tmp5_);
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp7_ = _tmp6_;
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (_tmp5_);
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		result = _tmp7_;
#line 340 "/home/jens/Source/shotwell/src/Resources.vala"
		return result;
#line 536 "Resources.c"
	} else {
		gchar** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
#line 341 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp8_ = names;
#line 341 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp8__length1 = names_length1;
#line 341 "/home/jens/Source/shotwell/src/Resources.vala"
		if (_tmp8__length1 == 2) {
#line 546 "Resources.c"
			const gchar* _tmp9_ = NULL;
			gchar** _tmp10_ = NULL;
			gint _tmp10__length1 = 0;
			const gchar* _tmp11_ = NULL;
			gchar* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			gchar** _tmp14_ = NULL;
			gint _tmp14__length1 = 0;
			const gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp9_ = _ ("Add Tags \"%s\" and \"%s\"");
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp10_ = names;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp10__length1 = names_length1;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp11_ = _tmp10_[0];
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp12_ = hierarchical_tag_utilities_get_basename (_tmp11_);
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp13_ = _tmp12_;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp14_ = names;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp14__length1 = names_length1;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp15_ = _tmp14_[1];
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp16_ = hierarchical_tag_utilities_get_basename (_tmp15_);
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp17_ = _tmp16_;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp18_ = g_strdup_printf (_tmp9_, _tmp13_, _tmp17_);
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp19_ = _tmp18_;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (_tmp17_);
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (_tmp13_);
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp19_;
#line 343 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 594 "Resources.c"
		} else {
			const gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
#line 348 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp20_ = C_ ("UndoRedo menu entry", "Add Tags");
#line 348 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp21_ = g_strdup (_tmp20_);
#line 348 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp21_;
#line 348 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 606 "Resources.c"
		}
	}
}


gchar* resources_delete_tag_menu (const gchar* name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 352 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 353 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("_Delete Tag \"%s\"");
#line 353 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = name;
#line 353 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup_printf (_tmp0_, _tmp1_);
#line 353 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 353 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 629 "Resources.c"
}


gchar* resources_delete_tag_label (const gchar* name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 356 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 357 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Delete Tag \"%s\"");
#line 357 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = name;
#line 357 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup_printf (_tmp0_, _tmp1_);
#line 357 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 357 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 650 "Resources.c"
}


gchar* resources_rename_tag_menu (const gchar* name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 365 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 366 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Re_name Tag \"%s\"...");
#line 366 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = name;
#line 366 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup_printf (_tmp0_, _tmp1_);
#line 366 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 366 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 671 "Resources.c"
}


gchar* resources_rename_tag_label (const gchar* old_name, const gchar* new_name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 369 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (old_name != NULL, NULL);
#line 369 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (new_name != NULL, NULL);
#line 370 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Rename Tag \"%s\" to \"%s\"");
#line 370 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = old_name;
#line 370 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = new_name;
#line 370 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = g_strdup_printf (_tmp0_, _tmp1_, _tmp2_);
#line 370 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp3_;
#line 370 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 697 "Resources.c"
}


gchar* resources_tag_photos_label (const gchar* name, gint count) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 378 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = count;
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp1_ == 1) {
#line 713 "Resources.c"
		const gchar* _tmp2_ = NULL;
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2_ = _ ("Tag Photo as \"%s\"");
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp2_;
#line 719 "Resources.c"
	} else {
		const gchar* _tmp3_ = NULL;
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp3_ = _ ("Tag Photos as \"%s\"");
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp3_;
#line 726 "Resources.c"
	}
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = name;
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = g_strdup_printf (_tmp0_, _tmp4_);
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp5_;
#line 379 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 736 "Resources.c"
}


gchar* resources_tag_photos_tooltip (const gchar* name, gint count) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 382 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 383 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = count;
#line 383 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp1_ == 1) {
#line 752 "Resources.c"
		const gchar* _tmp2_ = NULL;
#line 383 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2_ = _ ("Tag the selected photo as \"%s\"");
#line 383 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp2_;
#line 758 "Resources.c"
	} else {
		const gchar* _tmp3_ = NULL;
#line 384 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp3_ = _ ("Tag the selected photos as \"%s\"");
#line 384 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp3_;
#line 765 "Resources.c"
	}
#line 383 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = name;
#line 383 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = g_strdup_printf (_tmp0_, _tmp4_);
#line 383 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp5_;
#line 383 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 775 "Resources.c"
}


gchar* resources_untag_photos_menu (const gchar* name, gint count) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 387 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 388 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = count;
#line 388 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp1_ == 1) {
#line 791 "Resources.c"
		const gchar* _tmp2_ = NULL;
#line 388 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2_ = _ ("Remove Tag \"%s\" From _Photo");
#line 388 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp2_;
#line 797 "Resources.c"
	} else {
		const gchar* _tmp3_ = NULL;
#line 389 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp3_ = _ ("Remove Tag \"%s\" From _Photos");
#line 389 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp3_;
#line 804 "Resources.c"
	}
#line 388 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = name;
#line 388 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = g_strdup_printf (_tmp0_, _tmp4_);
#line 388 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp5_;
#line 388 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 814 "Resources.c"
}


gchar* resources_untag_photos_label (const gchar* name, gint count) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 392 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 393 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = count;
#line 393 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp1_ == 1) {
#line 830 "Resources.c"
		const gchar* _tmp2_ = NULL;
#line 393 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2_ = _ ("Remove Tag \"%s\" From Photo");
#line 393 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp2_;
#line 836 "Resources.c"
	} else {
		const gchar* _tmp3_ = NULL;
#line 394 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp3_ = _ ("Remove Tag \"%s\" From Photos");
#line 394 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp3_;
#line 843 "Resources.c"
	}
#line 393 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = name;
#line 393 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = g_strdup_printf (_tmp0_, _tmp4_);
#line 393 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp5_;
#line 393 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 853 "Resources.c"
}


gchar* resources_rename_tag_exists_message (const gchar* name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 397 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 398 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Unable to rename tag to \"%s\" because the tag already exists.");
#line 398 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = name;
#line 398 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup_printf (_tmp0_, _tmp1_);
#line 398 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 398 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 874 "Resources.c"
}


gchar* resources_rename_search_exists_message (const gchar* name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 401 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 402 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Unable to rename search to \"%s\" because the search already exists.");
#line 402 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = name;
#line 402 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup_printf (_tmp0_, _tmp1_);
#line 402 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 402 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 895 "Resources.c"
}


gchar* resources_rename_search_label (const gchar* old_name, const gchar* new_name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 413 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (old_name != NULL, NULL);
#line 413 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (new_name != NULL, NULL);
#line 414 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Rename Search \"%s\" to \"%s\"");
#line 414 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = old_name;
#line 414 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = new_name;
#line 414 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = g_strdup_printf (_tmp0_, _tmp1_, _tmp2_);
#line 414 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp3_;
#line 414 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 921 "Resources.c"
}


gchar* resources_delete_search_label (const gchar* name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 417 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 418 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Delete Search \"%s\"");
#line 418 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = name;
#line 418 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup_printf (_tmp0_, _tmp1_);
#line 418 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 418 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 942 "Resources.c"
}


const gchar* resources_rating_menu (Rating rating) {
	const gchar* result = NULL;
	Rating _tmp0_ = 0;
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = rating;
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
	switch (_tmp0_) {
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_REJECTED:
#line 955 "Resources.c"
		{
#line 424 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_REJECTED_MENU;
#line 424 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 961 "Resources.c"
		}
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_UNRATED:
#line 965 "Resources.c"
		{
#line 426 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_UNRATED_MENU;
#line 426 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 971 "Resources.c"
		}
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_ONE:
#line 975 "Resources.c"
		{
			const gchar* _tmp1_ = NULL;
#line 428 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = resources_RATE_ONE_MENU;
#line 428 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp1_;
#line 428 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 984 "Resources.c"
		}
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_TWO:
#line 988 "Resources.c"
		{
			const gchar* _tmp2_ = NULL;
#line 430 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp2_ = resources_RATE_TWO_MENU;
#line 430 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp2_;
#line 430 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 997 "Resources.c"
		}
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_THREE:
#line 1001 "Resources.c"
		{
			const gchar* _tmp3_ = NULL;
#line 432 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = resources_RATE_THREE_MENU;
#line 432 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp3_;
#line 432 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1010 "Resources.c"
		}
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FOUR:
#line 1014 "Resources.c"
		{
			const gchar* _tmp4_ = NULL;
#line 434 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = resources_RATE_FOUR_MENU;
#line 434 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp4_;
#line 434 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1023 "Resources.c"
		}
#line 422 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FIVE:
#line 1027 "Resources.c"
		{
			const gchar* _tmp5_ = NULL;
#line 436 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = resources_RATE_FIVE_MENU;
#line 436 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp5_;
#line 436 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1036 "Resources.c"
		}
		default:
		{
#line 438 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_UNRATED_MENU;
#line 438 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1044 "Resources.c"
		}
	}
}


const gchar* resources_rating_label (Rating rating) {
	const gchar* result = NULL;
	Rating _tmp0_ = 0;
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = rating;
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
	switch (_tmp0_) {
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_REJECTED:
#line 1059 "Resources.c"
		{
#line 445 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_REJECTED_LABEL;
#line 445 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1065 "Resources.c"
		}
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_UNRATED:
#line 1069 "Resources.c"
		{
#line 447 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_UNRATED_LABEL;
#line 447 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1075 "Resources.c"
		}
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_ONE:
#line 1079 "Resources.c"
		{
			const gchar* _tmp1_ = NULL;
#line 449 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = resources_RATE_ONE_LABEL;
#line 449 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp1_;
#line 449 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1088 "Resources.c"
		}
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_TWO:
#line 1092 "Resources.c"
		{
			const gchar* _tmp2_ = NULL;
#line 451 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp2_ = resources_RATE_TWO_LABEL;
#line 451 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp2_;
#line 451 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1101 "Resources.c"
		}
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_THREE:
#line 1105 "Resources.c"
		{
			const gchar* _tmp3_ = NULL;
#line 453 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = resources_RATE_THREE_LABEL;
#line 453 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp3_;
#line 453 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1114 "Resources.c"
		}
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FOUR:
#line 1118 "Resources.c"
		{
			const gchar* _tmp4_ = NULL;
#line 455 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = resources_RATE_FOUR_LABEL;
#line 455 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp4_;
#line 455 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1127 "Resources.c"
		}
#line 443 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FIVE:
#line 1131 "Resources.c"
		{
			const gchar* _tmp5_ = NULL;
#line 457 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = resources_RATE_FIVE_LABEL;
#line 457 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp5_;
#line 457 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1140 "Resources.c"
		}
		default:
		{
#line 459 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_UNRATED_LABEL;
#line 459 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1148 "Resources.c"
		}
	}
}


const gchar* resources_rating_combo_box (Rating rating) {
	const gchar* result = NULL;
	Rating _tmp0_ = 0;
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = rating;
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
	switch (_tmp0_) {
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_REJECTED:
#line 1163 "Resources.c"
		{
#line 466 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_REJECTED_COMBO_BOX;
#line 466 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1169 "Resources.c"
		}
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_UNRATED:
#line 1173 "Resources.c"
		{
#line 468 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_UNRATED_COMBO_BOX;
#line 468 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1179 "Resources.c"
		}
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_ONE:
#line 1183 "Resources.c"
		{
			const gchar* _tmp1_ = NULL;
#line 470 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = resources_RATE_ONE_MENU;
#line 470 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp1_;
#line 470 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1192 "Resources.c"
		}
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_TWO:
#line 1196 "Resources.c"
		{
			const gchar* _tmp2_ = NULL;
#line 472 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp2_ = resources_RATE_TWO_MENU;
#line 472 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp2_;
#line 472 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1205 "Resources.c"
		}
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_THREE:
#line 1209 "Resources.c"
		{
			const gchar* _tmp3_ = NULL;
#line 474 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = resources_RATE_THREE_MENU;
#line 474 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp3_;
#line 474 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1218 "Resources.c"
		}
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FOUR:
#line 1222 "Resources.c"
		{
			const gchar* _tmp4_ = NULL;
#line 476 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = resources_RATE_FOUR_MENU;
#line 476 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp4_;
#line 476 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1231 "Resources.c"
		}
#line 464 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FIVE:
#line 1235 "Resources.c"
		{
			const gchar* _tmp5_ = NULL;
#line 478 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = resources_RATE_FIVE_MENU;
#line 478 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp5_;
#line 478 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1244 "Resources.c"
		}
		default:
		{
#line 480 "/home/jens/Source/shotwell/src/Resources.vala"
			result = RESOURCES_RATE_UNRATED_MENU;
#line 480 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1252 "Resources.c"
		}
	}
}


gchar* resources_get_rating_filter_tooltip (RatingFilter filter) {
	gchar* result = NULL;
	RatingFilter _tmp0_ = 0;
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = filter;
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
	switch (_tmp0_) {
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_REJECTED_OR_HIGHER:
#line 1267 "Resources.c"
		{
			gchar* _tmp1_ = NULL;
#line 487 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = g_strdup (RESOURCES_DISPLAY_REJECTED_OR_HIGHER_TOOLTIP);
#line 487 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp1_;
#line 487 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1276 "Resources.c"
		}
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_ONE_OR_HIGHER:
#line 1280 "Resources.c"
		{
			const gchar* _tmp2_ = NULL;
			gchar* _tmp3_ = NULL;
#line 490 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp2_ = resources_DISPLAY_ONE_OR_HIGHER_TOOLTIP;
#line 490 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = g_strdup (_tmp2_);
#line 490 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp3_;
#line 490 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1292 "Resources.c"
		}
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_TWO_OR_HIGHER:
#line 1296 "Resources.c"
		{
			const gchar* _tmp4_ = NULL;
			gchar* _tmp5_ = NULL;
#line 493 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = resources_DISPLAY_TWO_OR_HIGHER_TOOLTIP;
#line 493 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = g_strdup (_tmp4_);
#line 493 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp5_;
#line 493 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1308 "Resources.c"
		}
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_THREE_OR_HIGHER:
#line 1312 "Resources.c"
		{
			const gchar* _tmp6_ = NULL;
			gchar* _tmp7_ = NULL;
#line 496 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp6_ = resources_DISPLAY_THREE_OR_HIGHER_TOOLTIP;
#line 496 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp7_ = g_strdup (_tmp6_);
#line 496 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp7_;
#line 496 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1324 "Resources.c"
		}
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_FOUR_OR_HIGHER:
#line 1328 "Resources.c"
		{
			const gchar* _tmp8_ = NULL;
			gchar* _tmp9_ = NULL;
#line 499 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp8_ = resources_DISPLAY_FOUR_OR_HIGHER_TOOLTIP;
#line 499 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp9_ = g_strdup (_tmp8_);
#line 499 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp9_;
#line 499 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1340 "Resources.c"
		}
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_FIVE_ONLY:
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_FIVE_OR_HIGHER:
#line 1346 "Resources.c"
		{
			const gchar* _tmp10_ = NULL;
			gchar* _tmp11_ = NULL;
#line 503 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp10_ = resources_DISPLAY_FIVE_OR_HIGHER_TOOLTIP;
#line 503 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp11_ = g_strdup (_tmp10_);
#line 503 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp11_;
#line 503 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1358 "Resources.c"
		}
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_REJECTED_ONLY:
#line 1362 "Resources.c"
		{
			gchar* _tmp12_ = NULL;
#line 506 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp12_ = g_strdup (RESOURCES_DISPLAY_REJECTED_ONLY_TOOLTIP);
#line 506 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp12_;
#line 506 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1371 "Resources.c"
		}
		default:
#line 485 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FILTER_UNRATED_OR_HIGHER:
#line 1376 "Resources.c"
		{
			gchar* _tmp13_ = NULL;
#line 510 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp13_ = g_strdup (RESOURCES_DISPLAY_UNRATED_OR_HIGHER_TOOLTIP);
#line 510 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp13_;
#line 510 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1385 "Resources.c"
		}
	}
}


gchar* resources_rating_progress (Rating rating) {
	gchar* result = NULL;
	Rating _tmp0_ = 0;
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = rating;
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
	switch (_tmp0_) {
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_REJECTED:
#line 1400 "Resources.c"
		{
			gchar* _tmp1_ = NULL;
#line 517 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = g_strdup (RESOURCES_RATE_REJECTED_PROGRESS);
#line 517 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp1_;
#line 517 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1409 "Resources.c"
		}
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_UNRATED:
#line 1413 "Resources.c"
		{
			gchar* _tmp2_ = NULL;
#line 519 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp2_ = g_strdup (RESOURCES_RATE_UNRATED_PROGRESS);
#line 519 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp2_;
#line 519 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1422 "Resources.c"
		}
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_ONE:
#line 1426 "Resources.c"
		{
			const gchar* _tmp3_ = NULL;
			gchar* _tmp4_ = NULL;
#line 521 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = resources_RATE_ONE_PROGRESS;
#line 521 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = g_strdup (_tmp3_);
#line 521 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp4_;
#line 521 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1438 "Resources.c"
		}
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_TWO:
#line 1442 "Resources.c"
		{
			const gchar* _tmp5_ = NULL;
			gchar* _tmp6_ = NULL;
#line 523 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = resources_RATE_TWO_PROGRESS;
#line 523 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp6_ = g_strdup (_tmp5_);
#line 523 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp6_;
#line 523 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1454 "Resources.c"
		}
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_THREE:
#line 1458 "Resources.c"
		{
			const gchar* _tmp7_ = NULL;
			gchar* _tmp8_ = NULL;
#line 525 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp7_ = resources_RATE_THREE_PROGRESS;
#line 525 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp8_ = g_strdup (_tmp7_);
#line 525 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp8_;
#line 525 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1470 "Resources.c"
		}
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FOUR:
#line 1474 "Resources.c"
		{
			const gchar* _tmp9_ = NULL;
			gchar* _tmp10_ = NULL;
#line 527 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp9_ = resources_RATE_FOUR_PROGRESS;
#line 527 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp10_ = g_strdup (_tmp9_);
#line 527 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp10_;
#line 527 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1486 "Resources.c"
		}
#line 515 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FIVE:
#line 1490 "Resources.c"
		{
			const gchar* _tmp11_ = NULL;
			gchar* _tmp12_ = NULL;
#line 529 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp11_ = resources_RATE_FIVE_PROGRESS;
#line 529 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp12_ = g_strdup (_tmp11_);
#line 529 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp12_;
#line 529 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1502 "Resources.c"
		}
		default:
		{
			gchar* _tmp13_ = NULL;
#line 531 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp13_ = g_strdup (RESOURCES_RATE_UNRATED_PROGRESS);
#line 531 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp13_;
#line 531 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1513 "Resources.c"
		}
	}
}


gchar* resources_get_stars (Rating rating) {
	gchar* result = NULL;
	Rating _tmp0_ = 0;
#line 538 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = rating;
#line 538 "/home/jens/Source/shotwell/src/Resources.vala"
	switch (_tmp0_) {
#line 538 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_ONE:
#line 1528 "Resources.c"
		{
			gchar* _tmp1_ = NULL;
#line 540 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = g_strdup ("\xE2\x98\x85");
#line 540 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp1_;
#line 540 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1537 "Resources.c"
		}
#line 538 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_TWO:
#line 1541 "Resources.c"
		{
			gchar* _tmp2_ = NULL;
#line 542 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp2_ = g_strdup ("\xE2\x98\x85\xE2\x98\x85");
#line 542 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp2_;
#line 542 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1550 "Resources.c"
		}
#line 538 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_THREE:
#line 1554 "Resources.c"
		{
			gchar* _tmp3_ = NULL;
#line 544 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = g_strdup ("\xE2\x98\x85\xE2\x98\x85\xE2\x98\x85");
#line 544 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp3_;
#line 544 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1563 "Resources.c"
		}
#line 538 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FOUR:
#line 1567 "Resources.c"
		{
			gchar* _tmp4_ = NULL;
#line 546 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = g_strdup ("\xE2\x98\x85\xE2\x98\x85\xE2\x98\x85\xE2\x98\x85");
#line 546 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp4_;
#line 546 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1576 "Resources.c"
		}
#line 538 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FIVE:
#line 1580 "Resources.c"
		{
			gchar* _tmp5_ = NULL;
#line 548 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = g_strdup ("\xE2\x98\x85\xE2\x98\x85\xE2\x98\x85\xE2\x98\x85\xE2\x98\x85");
#line 548 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp5_;
#line 548 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1589 "Resources.c"
		}
		default:
		{
			gchar* _tmp6_ = NULL;
#line 550 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp6_ = g_strdup ("");
#line 550 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp6_;
#line 550 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1600 "Resources.c"
		}
	}
}


GdkPixbuf* resources_get_rating_trinket (Rating rating, gint scale) {
	GdkPixbuf* result = NULL;
	Rating _tmp0_ = 0;
#line 555 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = rating;
#line 555 "/home/jens/Source/shotwell/src/Resources.vala"
	switch (_tmp0_) {
#line 555 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_REJECTED:
#line 1615 "Resources.c"
		{
			gint _tmp1_ = 0;
			GdkPixbuf* _tmp2_ = NULL;
#line 557 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = scale;
#line 557 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp2_ = resources_get_icon (RESOURCES_ICON_RATING_REJECTED, _tmp1_);
#line 557 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp2_;
#line 557 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1627 "Resources.c"
		}
#line 555 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_ONE:
#line 1631 "Resources.c"
		{
			gint _tmp3_ = 0;
			GdkPixbuf* _tmp4_ = NULL;
#line 560 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = scale;
#line 560 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = resources_get_icon (RESOURCES_ICON_RATING_ONE, _tmp3_);
#line 560 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp4_;
#line 560 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1643 "Resources.c"
		}
#line 555 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_TWO:
#line 1647 "Resources.c"
		{
			gint _tmp5_ = 0;
			GdkPixbuf* _tmp6_ = NULL;
#line 562 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = scale;
#line 562 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp6_ = resources_get_icon (RESOURCES_ICON_RATING_TWO, _tmp5_ * 2);
#line 562 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp6_;
#line 562 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1659 "Resources.c"
		}
#line 555 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_THREE:
#line 1663 "Resources.c"
		{
			gint _tmp7_ = 0;
			GdkPixbuf* _tmp8_ = NULL;
#line 564 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp7_ = scale;
#line 564 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp8_ = resources_get_icon (RESOURCES_ICON_RATING_THREE, _tmp7_ * 3);
#line 564 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp8_;
#line 564 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1675 "Resources.c"
		}
#line 555 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FOUR:
#line 1679 "Resources.c"
		{
			gint _tmp9_ = 0;
			GdkPixbuf* _tmp10_ = NULL;
#line 566 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp9_ = scale;
#line 566 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp10_ = resources_get_icon (RESOURCES_ICON_RATING_FOUR, _tmp9_ * 4);
#line 566 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp10_;
#line 566 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1691 "Resources.c"
		}
#line 555 "/home/jens/Source/shotwell/src/Resources.vala"
		case RATING_FIVE:
#line 1695 "Resources.c"
		{
			gint _tmp11_ = 0;
			GdkPixbuf* _tmp12_ = NULL;
#line 568 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp11_ = scale;
#line 568 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp12_ = resources_get_icon (RESOURCES_ICON_RATING_FIVE, _tmp11_ * 5);
#line 568 "/home/jens/Source/shotwell/src/Resources.vala"
			result = _tmp12_;
#line 568 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1707 "Resources.c"
		}
		default:
		{
#line 570 "/home/jens/Source/shotwell/src/Resources.vala"
			result = NULL;
#line 570 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 1715 "Resources.c"
		}
	}
}


void resources_generate_rating_strings (void) {
	gchar* menu_base = NULL;
	gchar* _tmp0_ = NULL;
	gchar* label_base = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* tooltip_base = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* progress_base = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* display_rating_menu_base = NULL;
	gchar* _tmp7_ = NULL;
	gchar* display_rating_label_base = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* display_rating_tooltip_base = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* display_rating_or_higher_menu_base = NULL;
	const gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* display_rating_or_higher_label_base = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* display_rating_or_higher_tooltip_base = NULL;
	const gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	gchar* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	gchar* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	gchar* _tmp37_ = NULL;
	gchar* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	gchar* _tmp43_ = NULL;
	gchar* _tmp44_ = NULL;
	gchar* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	gchar* _tmp49_ = NULL;
	gchar* _tmp50_ = NULL;
	gchar* _tmp51_ = NULL;
	gchar* _tmp52_ = NULL;
	gchar* _tmp53_ = NULL;
	gchar* _tmp54_ = NULL;
	gchar* _tmp55_ = NULL;
	gchar* _tmp56_ = NULL;
	gchar* _tmp57_ = NULL;
	gchar* _tmp58_ = NULL;
	gchar* _tmp59_ = NULL;
	gchar* _tmp60_ = NULL;
	gchar* _tmp61_ = NULL;
	gchar* _tmp62_ = NULL;
	gchar* _tmp63_ = NULL;
	gchar* _tmp64_ = NULL;
	gchar* _tmp65_ = NULL;
	gchar* _tmp66_ = NULL;
	gchar* _tmp67_ = NULL;
	gchar* _tmp68_ = NULL;
	gchar* _tmp69_ = NULL;
	gchar* _tmp70_ = NULL;
	gchar* _tmp71_ = NULL;
	gchar* _tmp72_ = NULL;
	gchar* _tmp73_ = NULL;
	gchar* _tmp74_ = NULL;
	gchar* _tmp75_ = NULL;
	gchar* _tmp76_ = NULL;
	gchar* _tmp77_ = NULL;
	gchar* _tmp78_ = NULL;
	gchar* _tmp79_ = NULL;
	gchar* _tmp80_ = NULL;
	gchar* _tmp81_ = NULL;
	gchar* _tmp82_ = NULL;
	gchar* _tmp83_ = NULL;
	gchar* _tmp84_ = NULL;
	gchar* _tmp85_ = NULL;
	gchar* _tmp86_ = NULL;
	gchar* _tmp87_ = NULL;
	gchar* _tmp88_ = NULL;
	gchar* _tmp89_ = NULL;
	gchar* _tmp90_ = NULL;
	gchar* _tmp91_ = NULL;
	gchar* _tmp92_ = NULL;
	gchar* _tmp93_ = NULL;
	gchar* _tmp94_ = NULL;
	gchar* _tmp95_ = NULL;
	gchar* _tmp96_ = NULL;
	gchar* _tmp97_ = NULL;
	gchar* _tmp98_ = NULL;
	gchar* _tmp99_ = NULL;
	gchar* _tmp100_ = NULL;
	gchar* _tmp101_ = NULL;
	gchar* _tmp102_ = NULL;
	gchar* _tmp103_ = NULL;
	gchar* _tmp104_ = NULL;
	gchar* _tmp105_ = NULL;
	gchar* _tmp106_ = NULL;
	gchar* _tmp107_ = NULL;
	gchar* _tmp108_ = NULL;
	gchar* _tmp109_ = NULL;
	gchar* _tmp110_ = NULL;
	gchar* _tmp111_ = NULL;
	gchar* _tmp112_ = NULL;
	gchar* _tmp113_ = NULL;
	gchar* _tmp114_ = NULL;
	gchar* _tmp115_ = NULL;
	gchar* _tmp116_ = NULL;
	gchar* _tmp117_ = NULL;
	gchar* _tmp118_ = NULL;
	gchar* _tmp119_ = NULL;
	gchar* _tmp120_ = NULL;
	gchar* _tmp121_ = NULL;
	gchar* _tmp122_ = NULL;
#line 575 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = g_strdup ("%s");
#line 575 "/home/jens/Source/shotwell/src/Resources.vala"
	menu_base = _tmp0_;
#line 576 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = _ ("Rate %s");
#line 576 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 576 "/home/jens/Source/shotwell/src/Resources.vala"
	label_base = _tmp2_;
#line 577 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = _ ("Set rating to %s");
#line 577 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 577 "/home/jens/Source/shotwell/src/Resources.vala"
	tooltip_base = _tmp4_;
#line 578 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = _ ("Setting rating to %s");
#line 578 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 578 "/home/jens/Source/shotwell/src/Resources.vala"
	progress_base = _tmp6_;
#line 579 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp7_ = g_strdup ("%s");
#line 579 "/home/jens/Source/shotwell/src/Resources.vala"
	display_rating_menu_base = _tmp7_;
#line 580 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp8_ = _ ("Display %s");
#line 580 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp9_ = g_strdup (_tmp8_);
#line 580 "/home/jens/Source/shotwell/src/Resources.vala"
	display_rating_label_base = _tmp9_;
#line 581 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp10_ = _ ("Only show photos with a rating of %s");
#line 581 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 581 "/home/jens/Source/shotwell/src/Resources.vala"
	display_rating_tooltip_base = _tmp11_;
#line 582 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp12_ = _ ("%s or Better");
#line 582 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp13_ = g_strdup (_tmp12_);
#line 582 "/home/jens/Source/shotwell/src/Resources.vala"
	display_rating_or_higher_menu_base = _tmp13_;
#line 583 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp14_ = _ ("Display %s or Better");
#line 583 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp15_ = g_strdup (_tmp14_);
#line 583 "/home/jens/Source/shotwell/src/Resources.vala"
	display_rating_or_higher_label_base = _tmp15_;
#line 584 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp16_ = _ ("Only show photos with a rating of %s or better");
#line 584 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 584 "/home/jens/Source/shotwell/src/Resources.vala"
	display_rating_or_higher_tooltip_base = _tmp17_;
#line 586 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp18_ = resources_get_stars (RATING_ONE);
#line 586 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp19_ = _tmp18_;
#line 586 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp20_ = g_strdup_printf (menu_base, _tmp19_);
#line 586 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_ONE_MENU);
#line 586 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_ONE_MENU = _tmp20_;
#line 586 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp19_);
#line 587 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp21_ = resources_get_stars (RATING_TWO);
#line 587 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp22_ = _tmp21_;
#line 587 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp23_ = g_strdup_printf (menu_base, _tmp22_);
#line 587 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_TWO_MENU);
#line 587 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_TWO_MENU = _tmp23_;
#line 587 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp22_);
#line 588 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp24_ = resources_get_stars (RATING_THREE);
#line 588 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp25_ = _tmp24_;
#line 588 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp26_ = g_strdup_printf (menu_base, _tmp25_);
#line 588 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_THREE_MENU);
#line 588 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_THREE_MENU = _tmp26_;
#line 588 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp25_);
#line 589 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp27_ = resources_get_stars (RATING_FOUR);
#line 589 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp28_ = _tmp27_;
#line 589 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp29_ = g_strdup_printf (menu_base, _tmp28_);
#line 589 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_FOUR_MENU);
#line 589 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_FOUR_MENU = _tmp29_;
#line 589 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp28_);
#line 590 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp30_ = resources_get_stars (RATING_FIVE);
#line 590 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp31_ = _tmp30_;
#line 590 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp32_ = g_strdup_printf (menu_base, _tmp31_);
#line 590 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_FIVE_MENU);
#line 590 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_FIVE_MENU = _tmp32_;
#line 590 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp31_);
#line 592 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp33_ = resources_get_stars (RATING_ONE);
#line 592 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp34_ = _tmp33_;
#line 592 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp35_ = g_strdup_printf (label_base, _tmp34_);
#line 592 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_ONE_LABEL);
#line 592 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_ONE_LABEL = _tmp35_;
#line 592 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp34_);
#line 593 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp36_ = resources_get_stars (RATING_TWO);
#line 593 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp37_ = _tmp36_;
#line 593 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp38_ = g_strdup_printf (label_base, _tmp37_);
#line 593 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_TWO_LABEL);
#line 593 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_TWO_LABEL = _tmp38_;
#line 593 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp37_);
#line 594 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp39_ = resources_get_stars (RATING_THREE);
#line 594 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp40_ = _tmp39_;
#line 594 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp41_ = g_strdup_printf (label_base, _tmp40_);
#line 594 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_THREE_LABEL);
#line 594 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_THREE_LABEL = _tmp41_;
#line 594 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp40_);
#line 595 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp42_ = resources_get_stars (RATING_FOUR);
#line 595 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp43_ = _tmp42_;
#line 595 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp44_ = g_strdup_printf (label_base, _tmp43_);
#line 595 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_FOUR_LABEL);
#line 595 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_FOUR_LABEL = _tmp44_;
#line 595 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp43_);
#line 596 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp45_ = resources_get_stars (RATING_FIVE);
#line 596 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp46_ = _tmp45_;
#line 596 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp47_ = g_strdup_printf (label_base, _tmp46_);
#line 596 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_FIVE_LABEL);
#line 596 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_FIVE_LABEL = _tmp47_;
#line 596 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp46_);
#line 598 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp48_ = resources_get_stars (RATING_ONE);
#line 598 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp49_ = _tmp48_;
#line 598 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp50_ = g_strdup_printf (tooltip_base, _tmp49_);
#line 598 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_ONE_TOOLTIP);
#line 598 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_ONE_TOOLTIP = _tmp50_;
#line 598 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp49_);
#line 599 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp51_ = resources_get_stars (RATING_TWO);
#line 599 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp52_ = _tmp51_;
#line 599 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp53_ = g_strdup_printf (tooltip_base, _tmp52_);
#line 599 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_TWO_TOOLTIP);
#line 599 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_TWO_TOOLTIP = _tmp53_;
#line 599 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp52_);
#line 600 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp54_ = resources_get_stars (RATING_THREE);
#line 600 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp55_ = _tmp54_;
#line 600 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp56_ = g_strdup_printf (tooltip_base, _tmp55_);
#line 600 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_THREE_TOOLTIP);
#line 600 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_THREE_TOOLTIP = _tmp56_;
#line 600 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp55_);
#line 601 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp57_ = resources_get_stars (RATING_FOUR);
#line 601 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp58_ = _tmp57_;
#line 601 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp59_ = g_strdup_printf (tooltip_base, _tmp58_);
#line 601 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_FOUR_TOOLTIP);
#line 601 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_FOUR_TOOLTIP = _tmp59_;
#line 601 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp58_);
#line 602 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp60_ = resources_get_stars (RATING_FIVE);
#line 602 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp61_ = _tmp60_;
#line 602 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp62_ = g_strdup_printf (tooltip_base, _tmp61_);
#line 602 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_FIVE_TOOLTIP);
#line 602 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_FIVE_TOOLTIP = _tmp62_;
#line 602 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp61_);
#line 604 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp63_ = resources_get_stars (RATING_ONE);
#line 604 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp64_ = _tmp63_;
#line 604 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp65_ = g_strdup_printf (progress_base, _tmp64_);
#line 604 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_ONE_PROGRESS);
#line 604 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_ONE_PROGRESS = _tmp65_;
#line 604 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp64_);
#line 605 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp66_ = resources_get_stars (RATING_TWO);
#line 605 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp67_ = _tmp66_;
#line 605 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp68_ = g_strdup_printf (progress_base, _tmp67_);
#line 605 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_TWO_PROGRESS);
#line 605 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_TWO_PROGRESS = _tmp68_;
#line 605 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp67_);
#line 606 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp69_ = resources_get_stars (RATING_THREE);
#line 606 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp70_ = _tmp69_;
#line 606 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp71_ = g_strdup_printf (progress_base, _tmp70_);
#line 606 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_THREE_PROGRESS);
#line 606 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_THREE_PROGRESS = _tmp71_;
#line 606 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp70_);
#line 607 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp72_ = resources_get_stars (RATING_FOUR);
#line 607 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp73_ = _tmp72_;
#line 607 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp74_ = g_strdup_printf (progress_base, _tmp73_);
#line 607 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_FOUR_PROGRESS);
#line 607 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_FOUR_PROGRESS = _tmp74_;
#line 607 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp73_);
#line 608 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp75_ = resources_get_stars (RATING_FIVE);
#line 608 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp76_ = _tmp75_;
#line 608 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp77_ = g_strdup_printf (progress_base, _tmp76_);
#line 608 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_RATE_FIVE_PROGRESS);
#line 608 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_RATE_FIVE_PROGRESS = _tmp77_;
#line 608 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp76_);
#line 610 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp78_ = resources_get_stars (RATING_ONE);
#line 610 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp79_ = _tmp78_;
#line 610 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp80_ = g_strdup_printf (display_rating_or_higher_menu_base, _tmp79_);
#line 610 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_ONE_OR_HIGHER_MENU);
#line 610 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_ONE_OR_HIGHER_MENU = _tmp80_;
#line 610 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp79_);
#line 611 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp81_ = resources_get_stars (RATING_TWO);
#line 611 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp82_ = _tmp81_;
#line 611 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp83_ = g_strdup_printf (display_rating_or_higher_menu_base, _tmp82_);
#line 611 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_TWO_OR_HIGHER_MENU);
#line 611 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_TWO_OR_HIGHER_MENU = _tmp83_;
#line 611 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp82_);
#line 612 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp84_ = resources_get_stars (RATING_THREE);
#line 612 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp85_ = _tmp84_;
#line 612 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp86_ = g_strdup_printf (display_rating_or_higher_menu_base, _tmp85_);
#line 612 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_THREE_OR_HIGHER_MENU);
#line 612 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_THREE_OR_HIGHER_MENU = _tmp86_;
#line 612 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp85_);
#line 613 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp87_ = resources_get_stars (RATING_FOUR);
#line 613 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp88_ = _tmp87_;
#line 613 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp89_ = g_strdup_printf (display_rating_or_higher_menu_base, _tmp88_);
#line 613 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_FOUR_OR_HIGHER_MENU);
#line 613 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_FOUR_OR_HIGHER_MENU = _tmp89_;
#line 613 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp88_);
#line 614 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp90_ = resources_get_stars (RATING_FIVE);
#line 614 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp91_ = _tmp90_;
#line 614 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp92_ = g_strdup_printf (display_rating_menu_base, _tmp91_);
#line 614 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_FIVE_OR_HIGHER_MENU);
#line 614 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_FIVE_OR_HIGHER_MENU = _tmp92_;
#line 614 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp91_);
#line 616 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp93_ = resources_get_stars (RATING_ONE);
#line 616 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp94_ = _tmp93_;
#line 616 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp95_ = g_strdup_printf (display_rating_or_higher_label_base, _tmp94_);
#line 616 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_ONE_OR_HIGHER_LABEL);
#line 616 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_ONE_OR_HIGHER_LABEL = _tmp95_;
#line 616 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp94_);
#line 617 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp96_ = resources_get_stars (RATING_TWO);
#line 617 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp97_ = _tmp96_;
#line 617 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp98_ = g_strdup_printf (display_rating_or_higher_label_base, _tmp97_);
#line 617 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_TWO_OR_HIGHER_LABEL);
#line 617 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_TWO_OR_HIGHER_LABEL = _tmp98_;
#line 617 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp97_);
#line 618 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp99_ = resources_get_stars (RATING_THREE);
#line 618 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp100_ = _tmp99_;
#line 618 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp101_ = g_strdup_printf (display_rating_or_higher_label_base, _tmp100_);
#line 618 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_THREE_OR_HIGHER_LABEL);
#line 618 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_THREE_OR_HIGHER_LABEL = _tmp101_;
#line 618 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp100_);
#line 619 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp102_ = resources_get_stars (RATING_FOUR);
#line 619 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp103_ = _tmp102_;
#line 619 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp104_ = g_strdup_printf (display_rating_or_higher_label_base, _tmp103_);
#line 619 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_FOUR_OR_HIGHER_LABEL);
#line 619 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_FOUR_OR_HIGHER_LABEL = _tmp104_;
#line 619 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp103_);
#line 620 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp105_ = resources_get_stars (RATING_FIVE);
#line 620 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp106_ = _tmp105_;
#line 620 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp107_ = g_strdup_printf (display_rating_label_base, _tmp106_);
#line 620 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_FIVE_OR_HIGHER_LABEL);
#line 620 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_FIVE_OR_HIGHER_LABEL = _tmp107_;
#line 620 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp106_);
#line 622 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp108_ = resources_get_stars (RATING_ONE);
#line 622 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp109_ = _tmp108_;
#line 622 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp110_ = g_strdup_printf (display_rating_or_higher_tooltip_base, _tmp109_);
#line 622 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_ONE_OR_HIGHER_TOOLTIP);
#line 622 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_ONE_OR_HIGHER_TOOLTIP = _tmp110_;
#line 622 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp109_);
#line 623 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp111_ = resources_get_stars (RATING_TWO);
#line 623 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp112_ = _tmp111_;
#line 623 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp113_ = g_strdup_printf (display_rating_or_higher_tooltip_base, _tmp112_);
#line 623 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_TWO_OR_HIGHER_TOOLTIP);
#line 623 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_TWO_OR_HIGHER_TOOLTIP = _tmp113_;
#line 623 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp112_);
#line 624 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp114_ = resources_get_stars (RATING_THREE);
#line 624 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp115_ = _tmp114_;
#line 624 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp116_ = g_strdup_printf (display_rating_or_higher_tooltip_base, _tmp115_);
#line 624 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_THREE_OR_HIGHER_TOOLTIP);
#line 624 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_THREE_OR_HIGHER_TOOLTIP = _tmp116_;
#line 624 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp115_);
#line 625 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp117_ = resources_get_stars (RATING_FOUR);
#line 625 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp118_ = _tmp117_;
#line 625 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp119_ = g_strdup_printf (display_rating_or_higher_tooltip_base, _tmp118_);
#line 625 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_FOUR_OR_HIGHER_TOOLTIP);
#line 625 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_FOUR_OR_HIGHER_TOOLTIP = _tmp119_;
#line 625 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp118_);
#line 626 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp120_ = resources_get_stars (RATING_FIVE);
#line 626 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp121_ = _tmp120_;
#line 626 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp122_ = g_strdup_printf (display_rating_tooltip_base, _tmp121_);
#line 626 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_DISPLAY_FIVE_OR_HIGHER_TOOLTIP);
#line 626 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_DISPLAY_FIVE_OR_HIGHER_TOOLTIP = _tmp122_;
#line 626 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp121_);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (display_rating_or_higher_tooltip_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (display_rating_or_higher_label_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (display_rating_or_higher_menu_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (display_rating_tooltip_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (display_rating_label_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (display_rating_menu_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (progress_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (tooltip_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (label_base);
#line 574 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (menu_base);
#line 2351 "Resources.c"
}


gchar* resources_jump_to_file_failed (GError* err) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 685 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = _ ("Unable to open in file manager: %s");
#line 685 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = err;
#line 685 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = _tmp1_->message;
#line 685 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = g_strdup_printf (_tmp0_, _tmp2_);
#line 685 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp3_;
#line 685 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2373 "Resources.c"
}


static void _dim_pixbuf_resources_add_stock_icon_modify (GdkPixbuf* pixbuf, gpointer self) {
#line 726 "/home/jens/Source/shotwell/src/Resources.vala"
	dim_pixbuf (pixbuf);
#line 2380 "Resources.c"
}


void resources_init (void) {
	GtkIconFactory* _tmp0_ = NULL;
	GFile* icons_dir = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	GFile* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
	GFile* _tmp7_ = NULL;
	GFile* _tmp8_ = NULL;
	GFile* _tmp9_ = NULL;
	GFile* _tmp10_ = NULL;
	GFile* _tmp11_ = NULL;
	GFile* _tmp12_ = NULL;
	GFile* _tmp13_ = NULL;
	GFile* _tmp14_ = NULL;
	GFile* _tmp15_ = NULL;
	GFile* _tmp16_ = NULL;
	GFile* _tmp17_ = NULL;
	GFile* _tmp18_ = NULL;
	GFile* _tmp19_ = NULL;
	GFile* _tmp20_ = NULL;
	GFile* _tmp21_ = NULL;
	GFile* _tmp22_ = NULL;
	GThemedIcon* _tmp23_ = NULL;
	GThemedIcon* _tmp24_ = NULL;
	GThemedIcon* _tmp25_ = NULL;
	GThemedIcon* _tmp26_ = NULL;
	GThemedIcon* _tmp27_ = NULL;
	GThemedIcon* _tmp28_ = NULL;
	GThemedIcon* _tmp29_ = NULL;
	GThemedIcon* _tmp30_ = NULL;
	GThemedIcon* _tmp31_ = NULL;
	GThemedIcon* _tmp32_ = NULL;
	GThemedIcon* _tmp33_ = NULL;
	GThemedIcon* _tmp34_ = NULL;
	GThemedIcon* _tmp35_ = NULL;
	GThemedIcon* _tmp36_ = NULL;
	GThemedIcon* _tmp37_ = NULL;
	GThemedIcon* _tmp38_ = NULL;
	GtkIconFactory* _tmp39_ = NULL;
#line 709 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = gtk_icon_factory_new ();
#line 709 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (resources_factory);
#line 709 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_factory = _tmp0_;
#line 711 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = app_dirs_get_resources_dir ();
#line 711 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = _tmp1_;
#line 711 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = g_file_get_child (_tmp2_, "icons");
#line 711 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = _tmp3_;
#line 711 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp2_);
#line 711 "/home/jens/Source/shotwell/src/Resources.vala"
	icons_dir = _tmp4_;
#line 712 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = g_file_get_child (icons_dir, "crop.svg");
#line 712 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp6_ = _tmp5_;
#line 712 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp6_, RESOURCES_CROP);
#line 712 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp6_);
#line 713 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp7_ = g_file_get_child (icons_dir, "redeye.png");
#line 713 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp8_ = _tmp7_;
#line 713 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp8_, RESOURCES_REDEYE);
#line 713 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp8_);
#line 714 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp9_ = g_file_get_child (icons_dir, "make-primary.svg");
#line 714 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp10_ = _tmp9_;
#line 714 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp10_, RESOURCES_MAKE_PRIMARY);
#line 714 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp10_);
#line 715 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp11_ = g_file_get_child (icons_dir, "import.svg");
#line 715 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp12_ = _tmp11_;
#line 715 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp12_, RESOURCES_IMPORT);
#line 715 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp12_);
#line 716 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp13_ = g_file_get_child (icons_dir, "straighten.svg");
#line 716 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp14_ = _tmp13_;
#line 716 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp14_, RESOURCES_STRAIGHTEN);
#line 716 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp14_);
#line 717 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp15_ = g_file_get_child (icons_dir, "import-all.png");
#line 717 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp16_ = _tmp15_;
#line 717 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp16_, RESOURCES_IMPORT_ALL);
#line 717 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp16_);
#line 718 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp17_ = g_file_get_child (icons_dir, "shotwell-auto-enhance.png");
#line 718 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp18_ = _tmp17_;
#line 718 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp18_, RESOURCES_ENHANCE);
#line 718 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp18_);
#line 719 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp19_ = g_file_get_child (icons_dir, "crop-pivot-reticle.png");
#line 719 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp20_ = _tmp19_;
#line 719 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp20_, RESOURCES_CROP_PIVOT_RETICLE);
#line 719 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp20_);
#line 720 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp21_ = g_file_get_child (icons_dir, "merge.svg");
#line 720 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp22_ = _tmp21_;
#line 720 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon (_tmp22_, RESOURCES_MERGE);
#line 720 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp22_);
#line 721 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp23_ = (GThemedIcon*) g_themed_icon_new (RESOURCES_ICON_FLAGGED_PAGE);
#line 721 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp24_ = _tmp23_;
#line 721 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon_from_themed_icon (_tmp24_, RESOURCES_ICON_FLAGGED_PAGE, NULL, NULL);
#line 721 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp24_);
#line 722 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp25_ = (GThemedIcon*) g_themed_icon_new (RESOURCES_ICON_VIDEOS_PAGE);
#line 722 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp26_ = _tmp25_;
#line 722 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon_from_themed_icon (_tmp26_, RESOURCES_ICON_VIDEOS_PAGE, NULL, NULL);
#line 722 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp26_);
#line 723 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp27_ = (GThemedIcon*) g_themed_icon_new (RESOURCES_ICON_SINGLE_PHOTO);
#line 723 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp28_ = _tmp27_;
#line 723 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon_from_themed_icon (_tmp28_, RESOURCES_ICON_SINGLE_PHOTO, NULL, NULL);
#line 723 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp28_);
#line 724 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp29_ = (GThemedIcon*) g_themed_icon_new (RESOURCES_ICON_CAMERAS);
#line 724 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp30_ = _tmp29_;
#line 724 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon_from_themed_icon (_tmp30_, RESOURCES_ICON_CAMERAS, NULL, NULL);
#line 724 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp30_);
#line 726 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp31_ = (GThemedIcon*) g_themed_icon_new (RESOURCES_ICON_FILTER_FLAGGED);
#line 726 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp32_ = _tmp31_;
#line 726 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon_from_themed_icon (_tmp32_, RESOURCES_ICON_FILTER_FLAGGED_DISABLED, _dim_pixbuf_resources_add_stock_icon_modify, NULL);
#line 726 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp32_);
#line 728 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp33_ = (GThemedIcon*) g_themed_icon_new (RESOURCES_ICON_FILTER_PHOTOS);
#line 728 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp34_ = _tmp33_;
#line 728 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon_from_themed_icon (_tmp34_, RESOURCES_ICON_FILTER_PHOTOS_DISABLED, _dim_pixbuf_resources_add_stock_icon_modify, NULL);
#line 728 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp34_);
#line 730 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp35_ = (GThemedIcon*) g_themed_icon_new (RESOURCES_ICON_FILTER_VIDEOS);
#line 730 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp36_ = _tmp35_;
#line 730 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon_from_themed_icon (_tmp36_, RESOURCES_ICON_FILTER_VIDEOS_DISABLED, _dim_pixbuf_resources_add_stock_icon_modify, NULL);
#line 730 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp36_);
#line 732 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp37_ = (GThemedIcon*) g_themed_icon_new (RESOURCES_ICON_FILTER_RAW);
#line 732 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp38_ = _tmp37_;
#line 732 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_add_stock_icon_from_themed_icon (_tmp38_, RESOURCES_ICON_FILTER_RAW_DISABLED, _dim_pixbuf_resources_add_stock_icon_modify, NULL);
#line 732 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp38_);
#line 735 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp39_ = resources_factory;
#line 735 "/home/jens/Source/shotwell/src/Resources.vala"
	gtk_icon_factory_add_default (_tmp39_);
#line 737 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_generate_rating_strings ();
#line 707 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (icons_dir);
#line 2588 "Resources.c"
}


void resources_terminate (void) {
}


/**
     * @brief Helper for getting a format string that matches the
     * user's LC_TIME settings from the system.  This is intended 
     * to help support the use case where a user wants the text 
     * from one locale, but the timestamp format of another.
     * 
     * Stolen wholesale from code written for Geary by Jim Nelson
     * and from Marcel Stimberg's original patch to Shotwell to 
     * try to fix this; both are graciously thanked for their help.
     */
void resources_fetch_lc_time_format (void) {
	gchar* old_language = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* old_messages = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* lc_time = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	const gchar* _tmp24_ = NULL;
#line 756 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = g_getenv ("LANGUAGE");
#line 756 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 756 "/home/jens/Source/shotwell/src/Resources.vala"
	old_language = _tmp1_;
#line 757 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = old_language;
#line 757 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp2_ != NULL) {
#line 758 "/home/jens/Source/shotwell/src/Resources.vala"
		g_unsetenv ("LANGUAGE");
#line 2645 "Resources.c"
	}
#line 762 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = setlocale (LC_MESSAGES, NULL);
#line 762 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 762 "/home/jens/Source/shotwell/src/Resources.vala"
	old_messages = _tmp4_;
#line 763 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = setlocale (LC_TIME, NULL);
#line 763 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 763 "/home/jens/Source/shotwell/src/Resources.vala"
	lc_time = _tmp6_;
#line 765 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp7_ = lc_time;
#line 765 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp7_ != NULL) {
#line 2663 "Resources.c"
		const gchar* _tmp8_ = NULL;
#line 766 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp8_ = lc_time;
#line 766 "/home/jens/Source/shotwell/src/Resources.vala"
		setlocale (LC_MESSAGES, _tmp8_);
#line 2669 "Resources.c"
	}
#line 773 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp9_ = g_strdup ("%X");
#line 773 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_HH_MM_FORMAT_STRING);
#line 773 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_HH_MM_FORMAT_STRING = _tmp9_;
#line 778 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp10_ = nl_langinfo (T_FMT);
#line 778 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 778 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_HH_MM_SS_FORMAT_STRING);
#line 778 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_HH_MM_SS_FORMAT_STRING = _tmp11_;
#line 782 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp12_ = _ ("%a %b %d, %Y");
#line 782 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp13_ = g_strdup (_tmp12_);
#line 782 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_LONG_DATE_FORMAT_STRING);
#line 782 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_LONG_DATE_FORMAT_STRING = _tmp13_;
#line 787 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp14_ = C_ ("MultidayFormat", "%a %b %d");
#line 787 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp15_ = g_strdup (_tmp14_);
#line 787 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_START_MULTIDAY_DATE_FORMAT_STRING);
#line 787 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_START_MULTIDAY_DATE_FORMAT_STRING = _tmp15_;
#line 792 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp16_ = C_ ("MultidayFormat", "%d, %Y");
#line 792 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 792 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_END_MULTIDAY_DATE_FORMAT_STRING);
#line 792 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_END_MULTIDAY_DATE_FORMAT_STRING = _tmp17_;
#line 797 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp18_ = C_ ("MultimonthFormat", "%a %b %d");
#line 797 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp19_ = g_strdup (_tmp18_);
#line 797 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_START_MULTIMONTH_DATE_FORMAT_STRING);
#line 797 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_START_MULTIMONTH_DATE_FORMAT_STRING = _tmp19_;
#line 802 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp20_ = C_ ("MultimonthFormat", "%a %b %d, %Y");
#line 802 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp21_ = g_strdup (_tmp20_);
#line 802 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (resources_END_MULTIMONTH_DATE_FORMAT_STRING);
#line 802 "/home/jens/Source/shotwell/src/Resources.vala"
	resources_END_MULTIMONTH_DATE_FORMAT_STRING = _tmp21_;
#line 805 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp22_ = old_messages;
#line 805 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp22_ != NULL) {
#line 2729 "Resources.c"
		const gchar* _tmp23_ = NULL;
#line 806 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp23_ = old_messages;
#line 806 "/home/jens/Source/shotwell/src/Resources.vala"
		setlocale (LC_MESSAGES, _tmp23_);
#line 2735 "Resources.c"
	}
#line 809 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp24_ = old_language;
#line 809 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp24_ != NULL) {
#line 2741 "Resources.c"
		const gchar* _tmp25_ = NULL;
#line 810 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp25_ = old_language;
#line 810 "/home/jens/Source/shotwell/src/Resources.vala"
		g_setenv ("LANGUAGE", _tmp25_, TRUE);
#line 2747 "Resources.c"
	}
#line 753 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (lc_time);
#line 753 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (old_messages);
#line 753 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (old_language);
#line 2755 "Resources.c"
}


/**
     * @brief Returns a precached format string that matches the
     * user's LC_TIME settings.  
     */
gchar* resources_get_hh_mm_format_string (void) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 819 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_HH_MM_FORMAT_STRING;
#line 819 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 820 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_fetch_lc_time_format ();
#line 2774 "Resources.c"
	}
#line 823 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = resources_HH_MM_FORMAT_STRING;
#line 823 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 823 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 823 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2784 "Resources.c"
}


gchar* resources_get_hh_mm_ss_format_string (void) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 827 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_HH_MM_SS_FORMAT_STRING;
#line 827 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 828 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_fetch_lc_time_format ();
#line 2799 "Resources.c"
	}
#line 831 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = resources_HH_MM_SS_FORMAT_STRING;
#line 831 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 831 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 831 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2809 "Resources.c"
}


gchar* resources_get_long_date_format_string (void) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 835 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_LONG_DATE_FORMAT_STRING;
#line 835 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 836 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_fetch_lc_time_format ();
#line 2824 "Resources.c"
	}
#line 839 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = resources_LONG_DATE_FORMAT_STRING;
#line 839 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 839 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 839 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2834 "Resources.c"
}


gchar* resources_get_start_multiday_span_format_string (void) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 843 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_START_MULTIDAY_DATE_FORMAT_STRING;
#line 843 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 844 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_fetch_lc_time_format ();
#line 2849 "Resources.c"
	}
#line 847 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = resources_START_MULTIDAY_DATE_FORMAT_STRING;
#line 847 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 847 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 847 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2859 "Resources.c"
}


gchar* resources_get_end_multiday_span_format_string (void) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 851 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_END_MULTIDAY_DATE_FORMAT_STRING;
#line 851 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 852 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_fetch_lc_time_format ();
#line 2874 "Resources.c"
	}
#line 855 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = resources_END_MULTIDAY_DATE_FORMAT_STRING;
#line 855 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 855 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 855 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2884 "Resources.c"
}


gchar* resources_get_start_multimonth_span_format_string (void) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 859 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_START_MULTIMONTH_DATE_FORMAT_STRING;
#line 859 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 860 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_fetch_lc_time_format ();
#line 2899 "Resources.c"
	}
#line 863 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = resources_START_MULTIMONTH_DATE_FORMAT_STRING;
#line 863 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 863 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 863 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2909 "Resources.c"
}


gchar* resources_get_end_multimonth_span_format_string (void) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 867 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_END_MULTIMONTH_DATE_FORMAT_STRING;
#line 867 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 868 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_fetch_lc_time_format ();
#line 2924 "Resources.c"
	}
#line 871 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = resources_END_MULTIMONTH_DATE_FORMAT_STRING;
#line 871 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 871 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp2_;
#line 871 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2934 "Resources.c"
}


GFile* resources_get_ui (const gchar* filename) {
	GFile* result = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
#line 874 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (filename != NULL, NULL);
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = app_dirs_get_resources_dir ();
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = _tmp0_;
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_file_get_child (_tmp1_, "ui");
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = _tmp2_;
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = filename;
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = g_file_get_child (_tmp3_, _tmp4_);
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp6_ = _tmp5_;
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp3_);
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp1_);
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp6_;
#line 875 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 2971 "Resources.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 891 "/home/jens/Source/shotwell/src/Resources.vala"
	return self ? g_object_ref (self) : NULL;
#line 2978 "Resources.c"
}


GdkPixbuf* resources_get_noninterpretable_badge_pixbuf (void) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp14_ = NULL;
	GdkPixbuf* _tmp15_ = NULL;
	GError * _inner_error_ = NULL;
#line 882 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_noninterpretable_badge_pixbuf;
#line 882 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 2992 "Resources.c"
		{
			GdkPixbuf* _tmp1_ = NULL;
			GFile* _tmp2_ = NULL;
			GFile* _tmp3_ = NULL;
			GFile* _tmp4_ = NULL;
			GFile* _tmp5_ = NULL;
			GFile* _tmp6_ = NULL;
			GFile* _tmp7_ = NULL;
			gchar* _tmp8_ = NULL;
			gchar* _tmp9_ = NULL;
			GdkPixbuf* _tmp10_ = NULL;
			GdkPixbuf* _tmp11_ = NULL;
			GdkPixbuf* _tmp12_ = NULL;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp2_ = app_dirs_get_resources_dir ();
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = _tmp2_;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = g_file_get_child (_tmp3_, "icons");
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = _tmp4_;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp6_ = g_file_get_child (_tmp5_, RESOURCES_NONINTERPRETABLE_BADGE_FILE);
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp7_ = _tmp6_;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp8_ = g_file_get_path (_tmp7_);
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp9_ = _tmp8_;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp10_ = gdk_pixbuf_new_from_file (_tmp9_, &_inner_error_);
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp11_ = _tmp10_;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (_tmp9_);
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_object_unref0 (_tmp7_);
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_object_unref0 (_tmp5_);
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_object_unref0 (_tmp3_);
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = _tmp11_;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3038 "Resources.c"
				goto __catch416_g_error;
			}
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp12_ = _tmp1_;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp1_ = NULL;
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_object_unref0 (resources_noninterpretable_badge_pixbuf);
#line 884 "/home/jens/Source/shotwell/src/Resources.vala"
			resources_noninterpretable_badge_pixbuf = _tmp12_;
#line 883 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_object_unref0 (_tmp1_);
#line 3051 "Resources.c"
		}
		goto __finally416;
		__catch416_g_error:
		{
			GError* err = NULL;
			const gchar* _tmp13_ = NULL;
#line 883 "/home/jens/Source/shotwell/src/Resources.vala"
			err = _inner_error_;
#line 883 "/home/jens/Source/shotwell/src/Resources.vala"
			_inner_error_ = NULL;
#line 887 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp13_ = err->message;
#line 887 "/home/jens/Source/shotwell/src/Resources.vala"
			g_error ("Resources.vala:887: VideoReader can't load noninterpretable badge imag" \
"e: %s", _tmp13_);
#line 883 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_error_free0 (err);
#line 3068 "Resources.c"
		}
		__finally416:
#line 883 "/home/jens/Source/shotwell/src/Resources.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 883 "/home/jens/Source/shotwell/src/Resources.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 883 "/home/jens/Source/shotwell/src/Resources.vala"
			g_clear_error (&_inner_error_);
#line 883 "/home/jens/Source/shotwell/src/Resources.vala"
			return NULL;
#line 3079 "Resources.c"
		}
	}
#line 891 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp14_ = resources_noninterpretable_badge_pixbuf;
#line 891 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp15_ = _g_object_ref0 (_tmp14_);
#line 891 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp15_;
#line 891 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 3090 "Resources.c"
}


GtkIconTheme* resources_get_icon_theme_engine (void) {
	GtkIconTheme* result = NULL;
	GtkIconTheme* icon_theme = NULL;
	GtkIconTheme* _tmp0_ = NULL;
	GtkIconTheme* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	GFile* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 895 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = gtk_icon_theme_get_default ();
#line 895 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 895 "/home/jens/Source/shotwell/src/Resources.vala"
	icon_theme = _tmp1_;
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = app_dirs_get_resources_dir ();
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = _tmp2_;
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = g_file_get_child (_tmp3_, "icons");
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = _tmp4_;
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp6_ = g_file_get_path (_tmp5_);
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp7_ = _tmp6_;
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	gtk_icon_theme_append_search_path (icon_theme, _tmp7_);
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp7_);
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp5_);
#line 896 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp3_);
#line 898 "/home/jens/Source/shotwell/src/Resources.vala"
	result = icon_theme;
#line 898 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 3135 "Resources.c"
}


GdkPixbuf* resources_get_icon (const gchar* name, gint scale) {
	GdkPixbuf* result = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	GdkPixbuf* pixbuf = NULL;
	GeeHashMap* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gpointer _tmp14_ = NULL;
	GdkPixbuf* _tmp15_ = NULL;
	gint _tmp22_ = 0;
	GdkPixbuf* scaled_pixbuf = NULL;
	GdkPixbuf* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	GdkPixbuf* _tmp25_ = NULL;
	GeeHashMap* _tmp26_ = NULL;
	GeeHashMap* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	gint _tmp30_ = 0;
	gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	GdkPixbuf* _tmp33_ = NULL;
#line 903 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 904 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_scaled_icon_cache;
#line 904 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ != NULL) {
#line 3166 "Resources.c"
		gchar* scaled_name = NULL;
		const gchar* _tmp1_ = NULL;
		gint _tmp2_ = 0;
		gchar* _tmp3_ = NULL;
		GeeHashMap* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
#line 905 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp1_ = name;
#line 905 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2_ = scale;
#line 905 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp3_ = g_strdup_printf ("%s-%d", _tmp1_, _tmp2_);
#line 905 "/home/jens/Source/shotwell/src/Resources.vala"
		scaled_name = _tmp3_;
#line 906 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp4_ = resources_scaled_icon_cache;
#line 906 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp5_ = scaled_name;
#line 906 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp6_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp5_);
#line 906 "/home/jens/Source/shotwell/src/Resources.vala"
		if (_tmp6_) {
#line 3190 "Resources.c"
			GeeHashMap* _tmp7_ = NULL;
			const gchar* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
#line 907 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp7_ = resources_scaled_icon_cache;
#line 907 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp8_ = scaled_name;
#line 907 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp9_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp8_);
#line 907 "/home/jens/Source/shotwell/src/Resources.vala"
			result = (GdkPixbuf*) _tmp9_;
#line 907 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (scaled_name);
#line 907 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 3206 "Resources.c"
		}
#line 904 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (scaled_name);
#line 3210 "Resources.c"
	}
#line 912 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp10_ = resources_icon_cache;
#line 912 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp10_ == NULL) {
#line 3216 "Resources.c"
		GeeHashMap* _tmp11_ = NULL;
#line 913 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp11_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, GDK_TYPE_PIXBUF, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 913 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (resources_icon_cache);
#line 913 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_icon_cache = _tmp11_;
#line 3224 "Resources.c"
	}
#line 916 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp12_ = resources_icon_cache;
#line 916 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp13_ = name;
#line 916 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp14_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp13_);
#line 916 "/home/jens/Source/shotwell/src/Resources.vala"
	pixbuf = (GdkPixbuf*) _tmp14_;
#line 917 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp15_ = pixbuf;
#line 917 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp15_ == NULL) {
#line 3238 "Resources.c"
		const gchar* _tmp16_ = NULL;
		GdkPixbuf* _tmp17_ = NULL;
		GdkPixbuf* _tmp18_ = NULL;
		GeeHashMap* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		GdkPixbuf* _tmp21_ = NULL;
#line 918 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp16_ = name;
#line 918 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp17_ = resources_load_icon (_tmp16_, 0);
#line 918 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (pixbuf);
#line 918 "/home/jens/Source/shotwell/src/Resources.vala"
		pixbuf = _tmp17_;
#line 919 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp18_ = pixbuf;
#line 919 "/home/jens/Source/shotwell/src/Resources.vala"
		if (_tmp18_ == NULL) {
#line 920 "/home/jens/Source/shotwell/src/Resources.vala"
			result = NULL;
#line 920 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_object_unref0 (pixbuf);
#line 920 "/home/jens/Source/shotwell/src/Resources.vala"
			return result;
#line 3263 "Resources.c"
		}
#line 922 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp19_ = resources_icon_cache;
#line 922 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp20_ = name;
#line 922 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp21_ = pixbuf;
#line 922 "/home/jens/Source/shotwell/src/Resources.vala"
		gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp20_, _tmp21_);
#line 3273 "Resources.c"
	}
#line 925 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp22_ = scale;
#line 925 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp22_ <= 0) {
#line 926 "/home/jens/Source/shotwell/src/Resources.vala"
		result = pixbuf;
#line 926 "/home/jens/Source/shotwell/src/Resources.vala"
		return result;
#line 3283 "Resources.c"
	}
#line 928 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp23_ = pixbuf;
#line 928 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp24_ = scale;
#line 928 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp25_ = scale_pixbuf (_tmp23_, _tmp24_, GDK_INTERP_BILINEAR, FALSE);
#line 928 "/home/jens/Source/shotwell/src/Resources.vala"
	scaled_pixbuf = _tmp25_;
#line 930 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp26_ = resources_scaled_icon_cache;
#line 930 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp26_ == NULL) {
#line 3297 "Resources.c"
		GeeHashMap* _tmp27_ = NULL;
#line 931 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp27_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, GDK_TYPE_PIXBUF, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 931 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (resources_scaled_icon_cache);
#line 931 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_scaled_icon_cache = _tmp27_;
#line 3305 "Resources.c"
	}
#line 933 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp28_ = resources_scaled_icon_cache;
#line 933 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp29_ = name;
#line 933 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp30_ = scale;
#line 933 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp31_ = g_strdup_printf ("%s-%d", _tmp29_, _tmp30_);
#line 933 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp32_ = _tmp31_;
#line 933 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp33_ = scaled_pixbuf;
#line 933 "/home/jens/Source/shotwell/src/Resources.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp32_, _tmp33_);
#line 933 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp32_);
#line 935 "/home/jens/Source/shotwell/src/Resources.vala"
	result = scaled_pixbuf;
#line 935 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (pixbuf);
#line 935 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 3329 "Resources.c"
}


GdkPixbuf* resources_load_icon (const gchar* name, gint scale) {
	GdkPixbuf* result = NULL;
	GFile* icons_dir = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	GdkPixbuf* pixbuf = NULL;
	GdkPixbuf* _tmp16_ = NULL;
	GdkPixbuf* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	GError * _inner_error_ = NULL;
#line 938 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 939 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = app_dirs_get_resources_dir ();
#line 939 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = _tmp0_;
#line 939 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_file_get_child (_tmp1_, "icons");
#line 939 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = _tmp2_;
#line 939 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp1_);
#line 939 "/home/jens/Source/shotwell/src/Resources.vala"
	icons_dir = _tmp3_;
#line 941 "/home/jens/Source/shotwell/src/Resources.vala"
	pixbuf = NULL;
#line 3361 "Resources.c"
	{
		GdkPixbuf* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
		GFile* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GdkPixbuf* _tmp10_ = NULL;
		GdkPixbuf* _tmp11_ = NULL;
		GdkPixbuf* _tmp12_ = NULL;
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp5_ = name;
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp6_ = g_file_get_child (icons_dir, _tmp5_);
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp7_ = _tmp6_;
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp8_ = g_file_get_path (_tmp7_);
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp9_ = _tmp8_;
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp10_ = gdk_pixbuf_new_from_file (_tmp9_, &_inner_error_);
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp11_ = _tmp10_;
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (_tmp9_);
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (_tmp7_);
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp4_ = _tmp11_;
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3394 "Resources.c"
			goto __catch417_g_error;
		}
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp12_ = _tmp4_;
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp4_ = NULL;
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (pixbuf);
#line 943 "/home/jens/Source/shotwell/src/Resources.vala"
		pixbuf = _tmp12_;
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (_tmp4_);
#line 3407 "Resources.c"
	}
	goto __finally417;
	__catch417_g_error:
	{
		GError* err = NULL;
		const gchar* _tmp13_ = NULL;
		GError* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		err = _inner_error_;
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		_inner_error_ = NULL;
#line 945 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp13_ = name;
#line 945 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp14_ = err;
#line 945 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp15_ = _tmp14_->message;
#line 945 "/home/jens/Source/shotwell/src/Resources.vala"
		g_critical ("Resources.vala:945: Unable to load icon %s: %s", _tmp13_, _tmp15_);
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_error_free0 (err);
#line 3430 "Resources.c"
	}
	__finally417:
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (pixbuf);
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (icons_dir);
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		g_clear_error (&_inner_error_);
#line 942 "/home/jens/Source/shotwell/src/Resources.vala"
		return NULL;
#line 3445 "Resources.c"
	}
#line 948 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp16_ = pixbuf;
#line 948 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp16_ == NULL) {
#line 949 "/home/jens/Source/shotwell/src/Resources.vala"
		result = NULL;
#line 949 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (pixbuf);
#line 949 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (icons_dir);
#line 949 "/home/jens/Source/shotwell/src/Resources.vala"
		return result;
#line 3459 "Resources.c"
	}
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp18_ = scale;
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp18_ > 0) {
#line 3465 "Resources.c"
		GdkPixbuf* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		GdkPixbuf* _tmp21_ = NULL;
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp19_ = pixbuf;
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp20_ = scale;
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp21_ = scale_pixbuf (_tmp19_, _tmp20_, GDK_INTERP_BILINEAR, FALSE);
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (_tmp17_);
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp17_ = _tmp21_;
#line 3479 "Resources.c"
	} else {
		GdkPixbuf* _tmp22_ = NULL;
		GdkPixbuf* _tmp23_ = NULL;
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp22_ = pixbuf;
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp23_ = _g_object_ref0 (_tmp22_);
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (_tmp17_);
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp17_ = _tmp23_;
#line 3491 "Resources.c"
	}
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp17_;
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (pixbuf);
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (icons_dir);
#line 951 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 3501 "Resources.c"
}


void resources_add_stock_icon (GFile* file, const gchar* stock_id) {
	GdkPixbuf* pixbuf = NULL;
	GtkIconSet* icon_set = NULL;
	GdkPixbuf* _tmp10_ = NULL;
	GtkIconSet* _tmp11_ = NULL;
	GtkIconFactory* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	GError * _inner_error_ = NULL;
#line 954 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 954 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_if_fail (stock_id != NULL);
#line 955 "/home/jens/Source/shotwell/src/Resources.vala"
	pixbuf = NULL;
#line 3519 "Resources.c"
	{
		GdkPixbuf* _tmp0_ = NULL;
		GFile* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GdkPixbuf* _tmp4_ = NULL;
		GdkPixbuf* _tmp5_ = NULL;
		GdkPixbuf* _tmp6_ = NULL;
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp1_ = file;
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2_ = g_file_get_path (_tmp1_);
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp3_ = _tmp2_;
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp4_ = gdk_pixbuf_new_from_file (_tmp3_, &_inner_error_);
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp5_ = _tmp4_;
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (_tmp3_);
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = _tmp5_;
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3544 "Resources.c"
			goto __catch418_g_error;
		}
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp6_ = _tmp0_;
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp0_ = NULL;
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (pixbuf);
#line 957 "/home/jens/Source/shotwell/src/Resources.vala"
		pixbuf = _tmp6_;
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (_tmp0_);
#line 3557 "Resources.c"
	}
	goto __finally418;
	__catch418_g_error:
	{
		GError* err = NULL;
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
		err = _inner_error_;
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
		_inner_error_ = NULL;
#line 959 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp7_ = stock_id;
#line 959 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp8_ = err;
#line 959 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp9_ = _tmp8_->message;
#line 959 "/home/jens/Source/shotwell/src/Resources.vala"
		g_critical ("Resources.vala:959: Unable to load stock icon %s: %s", _tmp7_, _tmp9_);
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_error_free0 (err);
#line 3580 "Resources.c"
	}
	__finally418:
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (pixbuf);
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
		g_clear_error (&_inner_error_);
#line 956 "/home/jens/Source/shotwell/src/Resources.vala"
		return;
#line 3593 "Resources.c"
	}
#line 962 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp10_ = pixbuf;
#line 962 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp11_ = gtk_icon_set_new_from_pixbuf (_tmp10_);
#line 962 "/home/jens/Source/shotwell/src/Resources.vala"
	icon_set = _tmp11_;
#line 963 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp12_ = resources_factory;
#line 963 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp13_ = stock_id;
#line 963 "/home/jens/Source/shotwell/src/Resources.vala"
	gtk_icon_factory_add (_tmp12_, _tmp13_, icon_set);
#line 954 "/home/jens/Source/shotwell/src/Resources.vala"
	_gtk_icon_set_unref0 (icon_set);
#line 954 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (pixbuf);
#line 3611 "Resources.c"
}


void resources_add_stock_icon_from_themed_icon (GThemedIcon* gicon, const gchar* stock_id, ResourcesAddStockIconModify modify, void* modify_target) {
	GtkIconTheme* icon_theme = NULL;
	GtkIconTheme* _tmp0_ = NULL;
	GtkIconTheme* _tmp1_ = NULL;
	GtkIconTheme* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	GFile* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GtkIconInfo* info = NULL;
	GtkIconTheme* _tmp9_ = NULL;
	GThemedIcon* _tmp10_ = NULL;
	GtkIconInfo* _tmp11_ = NULL;
	GtkIconInfo* _tmp12_ = NULL;
	GError * _inner_error_ = NULL;
#line 968 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_if_fail (G_IS_THEMED_ICON (gicon));
#line 968 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_if_fail (stock_id != NULL);
#line 970 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = gtk_icon_theme_get_default ();
#line 970 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 970 "/home/jens/Source/shotwell/src/Resources.vala"
	icon_theme = _tmp1_;
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = icon_theme;
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = app_dirs_get_resources_dir ();
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = _tmp3_;
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = g_file_get_child (_tmp4_, "icons");
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp6_ = _tmp5_;
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp7_ = g_file_get_path (_tmp6_);
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp8_ = _tmp7_;
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	gtk_icon_theme_append_search_path (_tmp2_, _tmp8_);
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (_tmp8_);
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp6_);
#line 971 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp4_);
#line 973 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp9_ = icon_theme;
#line 973 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp10_ = gicon;
#line 973 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp11_ = gtk_icon_theme_lookup_by_gicon (_tmp9_, G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, G_TYPE_ICON, GIcon), RESOURCES_DEFAULT_ICON_SCALE, GTK_ICON_LOOKUP_FORCE_SIZE);
#line 973 "/home/jens/Source/shotwell/src/Resources.vala"
	info = _tmp11_;
#line 975 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp12_ = info;
#line 975 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp12_ == NULL) {
#line 3676 "Resources.c"
		const gchar* _tmp13_ = NULL;
#line 976 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp13_ = stock_id;
#line 976 "/home/jens/Source/shotwell/src/Resources.vala"
		g_debug ("Resources.vala:976: unable to load icon for: %s", _tmp13_);
#line 977 "/home/jens/Source/shotwell/src/Resources.vala"
		_gtk_icon_info_free0 (info);
#line 977 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (icon_theme);
#line 977 "/home/jens/Source/shotwell/src/Resources.vala"
		return;
#line 3688 "Resources.c"
	}
	{
		GdkPixbuf* pix = NULL;
		GtkIconInfo* _tmp14_ = NULL;
		GdkPixbuf* _tmp15_ = NULL;
		ResourcesAddStockIconModify _tmp16_ = NULL;
		void* _tmp16__target = NULL;
		GtkIconSet* icon_set = NULL;
		GdkPixbuf* _tmp19_ = NULL;
		GtkIconSet* _tmp20_ = NULL;
		GtkIconFactory* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		GtkIconSet* _tmp23_ = NULL;
#line 981 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp14_ = info;
#line 981 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp15_ = gtk_icon_info_load_icon (_tmp14_, &_inner_error_);
#line 981 "/home/jens/Source/shotwell/src/Resources.vala"
		pix = _tmp15_;
#line 981 "/home/jens/Source/shotwell/src/Resources.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3710 "Resources.c"
			goto __catch419_g_error;
		}
#line 982 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp16_ = modify;
#line 982 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp16__target = modify_target;
#line 982 "/home/jens/Source/shotwell/src/Resources.vala"
		if (_tmp16_ != NULL) {
#line 3719 "Resources.c"
			ResourcesAddStockIconModify _tmp17_ = NULL;
			void* _tmp17__target = NULL;
			GdkPixbuf* _tmp18_ = NULL;
#line 983 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp17_ = modify;
#line 983 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp17__target = modify_target;
#line 983 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp18_ = pix;
#line 983 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp17_ (_tmp18_, _tmp17__target);
#line 3731 "Resources.c"
		}
#line 985 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp19_ = pix;
#line 985 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp20_ = gtk_icon_set_new_from_pixbuf (_tmp19_);
#line 985 "/home/jens/Source/shotwell/src/Resources.vala"
		icon_set = _tmp20_;
#line 986 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp21_ = resources_factory;
#line 986 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp22_ = stock_id;
#line 986 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp23_ = icon_set;
#line 986 "/home/jens/Source/shotwell/src/Resources.vala"
		gtk_icon_factory_add (_tmp21_, _tmp22_, _tmp23_);
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		_gtk_icon_set_unref0 (icon_set);
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (pix);
#line 3751 "Resources.c"
	}
	goto __finally419;
	__catch419_g_error:
	{
		GError* err = NULL;
		GError* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		err = _inner_error_;
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		_inner_error_ = NULL;
#line 988 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp24_ = err;
#line 988 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp25_ = _tmp24_->message;
#line 988 "/home/jens/Source/shotwell/src/Resources.vala"
		g_debug ("Resources.vala:988: %s", _tmp25_);
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_error_free0 (err);
#line 3771 "Resources.c"
	}
	__finally419:
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		_gtk_icon_info_free0 (info);
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (icon_theme);
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		g_clear_error (&_inner_error_);
#line 980 "/home/jens/Source/shotwell/src/Resources.vala"
		return;
#line 3786 "Resources.c"
	}
#line 968 "/home/jens/Source/shotwell/src/Resources.vala"
	_gtk_icon_info_free0 (info);
#line 968 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (icon_theme);
#line 3792 "Resources.c"
}


gchar* resources_get_help_path (void) {
	gchar* result = NULL;
	GFile* help_dir = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	GFile* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	GFile* help_index = NULL;
	GFile* _tmp6_ = NULL;
	GFile* _tmp7_ = NULL;
	GFile* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = app_dirs_get_exec_dir ();
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = _tmp0_;
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = g_file_get_child (_tmp1_, "help");
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = _tmp2_;
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = g_file_get_child (_tmp3_, "C");
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = _tmp4_;
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp3_);
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (_tmp1_);
#line 1000 "/home/jens/Source/shotwell/src/Resources.vala"
	help_dir = _tmp5_;
#line 1001 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp6_ = help_dir;
#line 1001 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp7_ = g_file_get_child (_tmp6_, "index.page");
#line 1001 "/home/jens/Source/shotwell/src/Resources.vala"
	help_index = _tmp7_;
#line 1003 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp8_ = help_index;
#line 1003 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp9_ = g_file_query_exists (_tmp8_, NULL);
#line 1003 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp9_) {
#line 3840 "Resources.c"
		gchar* help_path = NULL;
		GFile* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
#line 1006 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp10_ = help_dir;
#line 1006 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp11_ = g_file_get_path (_tmp10_);
#line 1006 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (help_path);
#line 1006 "/home/jens/Source/shotwell/src/Resources.vala"
		help_path = _tmp11_;
#line 1008 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp12_ = help_path;
#line 1008 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp13_ = g_str_has_suffix (_tmp12_, "/");
#line 1008 "/home/jens/Source/shotwell/src/Resources.vala"
		if (!_tmp13_) {
#line 3860 "Resources.c"
			const gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
#line 1009 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp14_ = help_path;
#line 1009 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp15_ = g_strconcat (_tmp14_, "/", NULL);
#line 1009 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (help_path);
#line 1009 "/home/jens/Source/shotwell/src/Resources.vala"
			help_path = _tmp15_;
#line 3871 "Resources.c"
		}
#line 1012 "/home/jens/Source/shotwell/src/Resources.vala"
		result = help_path;
#line 1012 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (help_index);
#line 1012 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (help_dir);
#line 1012 "/home/jens/Source/shotwell/src/Resources.vala"
		return result;
#line 3881 "Resources.c"
	}
#line 1018 "/home/jens/Source/shotwell/src/Resources.vala"
	result = NULL;
#line 1018 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (help_index);
#line 1018 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (help_dir);
#line 1018 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 3891 "Resources.c"
}


void resources_launch_help (GdkScreen* screen, const gchar* anchor, GError** error) {
	gchar* help_path = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp27_ = NULL;
	GError * _inner_error_ = NULL;
#line 1021 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_if_fail (GDK_IS_SCREEN (screen));
#line 1022 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_get_help_path ();
#line 1022 "/home/jens/Source/shotwell/src/Resources.vala"
	help_path = _tmp0_;
#line 1024 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = help_path;
#line 1024 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp1_ != NULL) {
#line 3911 "Resources.c"
		const gchar* _tmp2_ = NULL;
		gchar** argv = NULL;
		gchar** _tmp6_ = NULL;
		gint argv_length1 = 0;
		gint _argv_size_ = 0;
		gchar** _tmp7_ = NULL;
		gint _tmp7__length1 = 0;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar** _tmp10_ = NULL;
		gint _tmp10__length1 = 0;
		const gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar** _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
		gchar* _tmp15_ = NULL;
		GPid pid = 0;
		gboolean _tmp16_ = FALSE;
		GFile* _tmp17_ = NULL;
		GFile* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar** _tmp21_ = NULL;
		gint _tmp21__length1 = 0;
		GPid _tmp22_ = 0;
		gboolean _tmp23_ = FALSE;
		gboolean _tmp24_ = FALSE;
		gchar** _tmp25_ = NULL;
		gint _tmp25__length1 = 0;
		const gchar* _tmp26_ = NULL;
#line 1028 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp2_ = anchor;
#line 1028 "/home/jens/Source/shotwell/src/Resources.vala"
		if (_tmp2_ != NULL) {
#line 3947 "Resources.c"
			const gchar* _tmp3_ = NULL;
			const gchar* _tmp4_ = NULL;
			gchar* _tmp5_ = NULL;
#line 1029 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp3_ = help_path;
#line 1029 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp4_ = anchor;
#line 1029 "/home/jens/Source/shotwell/src/Resources.vala"
			_tmp5_ = g_strconcat (_tmp3_, _tmp4_, NULL);
#line 1029 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (help_path);
#line 1029 "/home/jens/Source/shotwell/src/Resources.vala"
			help_path = _tmp5_;
#line 3961 "Resources.c"
		}
#line 1032 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp6_ = g_new0 (gchar*, 3 + 1);
#line 1032 "/home/jens/Source/shotwell/src/Resources.vala"
		argv = _tmp6_;
#line 1032 "/home/jens/Source/shotwell/src/Resources.vala"
		argv_length1 = 3;
#line 1032 "/home/jens/Source/shotwell/src/Resources.vala"
		_argv_size_ = argv_length1;
#line 1033 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp7_ = argv;
#line 1033 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp7__length1 = argv_length1;
#line 1033 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp8_ = g_strdup ("yelp");
#line 1033 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (_tmp7_[0]);
#line 1033 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp7_[0] = _tmp8_;
#line 1033 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp9_ = _tmp7_[0];
#line 1034 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp10_ = argv;
#line 1034 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp10__length1 = argv_length1;
#line 1034 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp11_ = help_path;
#line 1034 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp12_ = g_strdup (_tmp11_);
#line 1034 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (_tmp10_[1]);
#line 1034 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp10_[1] = _tmp12_;
#line 1034 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp13_ = _tmp10_[1];
#line 1035 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp14_ = argv;
#line 1035 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp14__length1 = argv_length1;
#line 1035 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (_tmp14_[2]);
#line 1035 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp14_[2] = NULL;
#line 1035 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp15_ = _tmp14_[2];
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp17_ = app_dirs_get_exec_dir ();
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp18_ = _tmp17_;
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp19_ = g_file_get_path (_tmp18_);
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp20_ = _tmp19_;
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp21_ = argv;
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp21__length1 = argv_length1;
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp23_ = g_spawn_async (_tmp20_, _tmp21_, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL, &_tmp22_, &_inner_error_);
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		pid = _tmp22_;
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp24_ = _tmp23_;
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (_tmp20_);
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (_tmp18_);
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp16_ = _tmp24_;
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
			g_propagate_error (error, _inner_error_);
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
			argv = (_vala_array_free (argv, argv_length1, (GDestroyNotify) g_free), NULL);
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (help_path);
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
			return;
#line 4041 "Resources.c"
		}
#line 1038 "/home/jens/Source/shotwell/src/Resources.vala"
		if (_tmp16_) {
#line 1040 "/home/jens/Source/shotwell/src/Resources.vala"
			argv = (_vala_array_free (argv, argv_length1, (GDestroyNotify) g_free), NULL);
#line 1040 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (help_path);
#line 1040 "/home/jens/Source/shotwell/src/Resources.vala"
			return;
#line 4051 "Resources.c"
		}
#line 1043 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp25_ = argv;
#line 1043 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp25__length1 = argv_length1;
#line 1043 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp26_ = _tmp25_[0];
#line 1043 "/home/jens/Source/shotwell/src/Resources.vala"
		g_warning ("Resources.vala:1043: Unable to launch %s", _tmp26_);
#line 1024 "/home/jens/Source/shotwell/src/Resources.vala"
		argv = (_vala_array_free (argv, argv_length1, (GDestroyNotify) g_free), NULL);
#line 4063 "Resources.c"
	}
#line 1047 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp27_ = anchor;
#line 1047 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp27_ != NULL) {
#line 4069 "Resources.c"
		GdkScreen* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp28_ = screen;
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp29_ = anchor;
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp30_ = g_strconcat ("help:shotwell", _tmp29_, NULL);
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp31_ = _tmp30_;
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
		sys_show_uri (_tmp28_, _tmp31_, &_inner_error_);
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_free0 (_tmp31_);
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
			g_propagate_error (error, _inner_error_);
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (help_path);
#line 1048 "/home/jens/Source/shotwell/src/Resources.vala"
			return;
#line 4094 "Resources.c"
		}
	} else {
		GdkScreen* _tmp32_ = NULL;
#line 1050 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp32_ = screen;
#line 1050 "/home/jens/Source/shotwell/src/Resources.vala"
		sys_show_uri (_tmp32_, "help:shotwell", &_inner_error_);
#line 1050 "/home/jens/Source/shotwell/src/Resources.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1050 "/home/jens/Source/shotwell/src/Resources.vala"
			g_propagate_error (error, _inner_error_);
#line 1050 "/home/jens/Source/shotwell/src/Resources.vala"
			_g_free0 (help_path);
#line 1050 "/home/jens/Source/shotwell/src/Resources.vala"
			return;
#line 4110 "Resources.c"
		}
	}
#line 1021 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_free0 (help_path);
#line 4115 "Resources.c"
}


gchar* resources_to_css_color (GdkRGBA* color) {
	gchar* result = NULL;
	gint r = 0;
	GdkRGBA _tmp0_ = {0};
	gdouble _tmp1_ = 0.0;
	gint g = 0;
	GdkRGBA _tmp2_ = {0};
	gdouble _tmp3_ = 0.0;
	gint b = 0;
	GdkRGBA _tmp4_ = {0};
	gdouble _tmp5_ = 0.0;
	gchar* _tmp6_ = NULL;
#line 1054 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_val_if_fail (color != NULL, NULL);
#line 1055 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = *color;
#line 1055 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp1_ = _tmp0_.red;
#line 1055 "/home/jens/Source/shotwell/src/Resources.vala"
	r = (gint) (_tmp1_ * 255);
#line 1056 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = *color;
#line 1056 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = _tmp2_.green;
#line 1056 "/home/jens/Source/shotwell/src/Resources.vala"
	g = (gint) (_tmp3_ * 255);
#line 1057 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = *color;
#line 1057 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp5_ = _tmp4_.blue;
#line 1057 "/home/jens/Source/shotwell/src/Resources.vala"
	b = (gint) (_tmp5_ * 255);
#line 1059 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp6_ = g_strdup_printf ("rgb(%d, %d, %d)", r, g, b);
#line 1059 "/home/jens/Source/shotwell/src/Resources.vala"
	result = _tmp6_;
#line 1059 "/home/jens/Source/shotwell/src/Resources.vala"
	return result;
#line 4157 "Resources.c"
}


void resources_style_widget (GtkWidget* widget, const gchar* stylesheet) {
	GeeMap* _tmp0_ = NULL;
	GeeMap* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GtkCssProvider* styler = NULL;
	GtkCssProvider* _tmp11_ = NULL;
	GtkWidget* _tmp17_ = NULL;
	GtkStyleContext* _tmp18_ = NULL;
	GtkCssProvider* _tmp19_ = NULL;
	GeeMap* _tmp20_ = NULL;
	GtkWidget* _tmp21_ = NULL;
	GtkCssProvider* _tmp22_ = NULL;
	GError * _inner_error_ = NULL;
#line 1066 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_if_fail (GTK_IS_WIDGET (widget));
#line 1066 "/home/jens/Source/shotwell/src/Resources.vala"
	g_return_if_fail (stylesheet != NULL);
#line 1067 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp0_ = resources_providers;
#line 1067 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp0_ == NULL) {
#line 4183 "Resources.c"
		GeeHashMap* _tmp1_ = NULL;
#line 1068 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp1_ = gee_hash_map_new (gtk_widget_get_type (), (GBoxedCopyFunc) g_object_ref, g_object_unref, GTK_TYPE_CSS_PROVIDER, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 1068 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (resources_providers);
#line 1068 "/home/jens/Source/shotwell/src/Resources.vala"
		resources_providers = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_MAP, GeeMap);
#line 4191 "Resources.c"
	}
#line 1070 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp2_ = resources_providers;
#line 1070 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp3_ = widget;
#line 1070 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp4_ = gee_map_has_key (_tmp2_, _tmp3_);
#line 1070 "/home/jens/Source/shotwell/src/Resources.vala"
	if (_tmp4_) {
#line 4201 "Resources.c"
		GtkWidget* _tmp5_ = NULL;
		GtkStyleContext* _tmp6_ = NULL;
		GeeMap* _tmp7_ = NULL;
		GtkWidget* _tmp8_ = NULL;
		gpointer _tmp9_ = NULL;
		GtkCssProvider* _tmp10_ = NULL;
#line 1071 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp5_ = widget;
#line 1071 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp6_ = gtk_widget_get_style_context (_tmp5_);
#line 1071 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp7_ = resources_providers;
#line 1071 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp8_ = widget;
#line 1071 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp9_ = gee_map_get (_tmp7_, _tmp8_);
#line 1071 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp10_ = (GtkCssProvider*) _tmp9_;
#line 1071 "/home/jens/Source/shotwell/src/Resources.vala"
		gtk_style_context_remove_provider (_tmp6_, G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GTK_TYPE_STYLE_PROVIDER, GtkStyleProvider));
#line 1071 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (_tmp10_);
#line 4224 "Resources.c"
	}
#line 1073 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp11_ = gtk_css_provider_new ();
#line 1073 "/home/jens/Source/shotwell/src/Resources.vala"
	styler = _tmp11_;
#line 4230 "Resources.c"
	{
		GtkCssProvider* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
#line 1076 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp12_ = styler;
#line 1076 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp13_ = stylesheet;
#line 1076 "/home/jens/Source/shotwell/src/Resources.vala"
		gtk_css_provider_load_from_data (_tmp12_, _tmp13_, (gssize) RESOURCES_ALL_DATA, &_inner_error_);
#line 1076 "/home/jens/Source/shotwell/src/Resources.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4242 "Resources.c"
			goto __catch420_g_error;
		}
	}
	goto __finally420;
	__catch420_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 1075 "/home/jens/Source/shotwell/src/Resources.vala"
		e = _inner_error_;
#line 1075 "/home/jens/Source/shotwell/src/Resources.vala"
		_inner_error_ = NULL;
#line 1078 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp14_ = stylesheet;
#line 1078 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp15_ = e;
#line 1078 "/home/jens/Source/shotwell/src/Resources.vala"
		_tmp16_ = _tmp15_->message;
#line 1078 "/home/jens/Source/shotwell/src/Resources.vala"
		g_warning ("Resources.vala:1078: couldn't parse widget stylesheet '%s': %s", _tmp14_, _tmp16_);
#line 1082 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_error_free0 (e);
#line 1082 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (styler);
#line 1082 "/home/jens/Source/shotwell/src/Resources.vala"
		return;
#line 4271 "Resources.c"
	}
	__finally420:
#line 1075 "/home/jens/Source/shotwell/src/Resources.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1075 "/home/jens/Source/shotwell/src/Resources.vala"
		_g_object_unref0 (styler);
#line 1075 "/home/jens/Source/shotwell/src/Resources.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1075 "/home/jens/Source/shotwell/src/Resources.vala"
		g_clear_error (&_inner_error_);
#line 1075 "/home/jens/Source/shotwell/src/Resources.vala"
		return;
#line 4284 "Resources.c"
	}
#line 1085 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp17_ = widget;
#line 1085 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp18_ = gtk_widget_get_style_context (_tmp17_);
#line 1085 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp19_ = styler;
#line 1085 "/home/jens/Source/shotwell/src/Resources.vala"
	gtk_style_context_add_provider (_tmp18_, G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GTK_TYPE_STYLE_PROVIDER, GtkStyleProvider), (guint) GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
#line 1088 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp20_ = resources_providers;
#line 1088 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp21_ = widget;
#line 1088 "/home/jens/Source/shotwell/src/Resources.vala"
	_tmp22_ = styler;
#line 1088 "/home/jens/Source/shotwell/src/Resources.vala"
	gee_map_set (_tmp20_, _tmp21_, _tmp22_);
#line 1066 "/home/jens/Source/shotwell/src/Resources.vala"
	_g_object_unref0 (styler);
#line 4304 "Resources.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



